c ******************************************************************
c *                                                                *
c *                       PROGRAM 'BCDENT'                         *
c *                                                                *
c *   Program 'BCDENT' is for the analysis of the behavior of      *
c *   multiply dented tubular members with different boundary      *
c *   conditions ----  pinned, and  elastically  restrainted,      * 
c *   subjected to  axial  compression combined  with biaxial      *
c *   bending  due to  end  moments, and/or  lateral loads --      * 
c *   linearly  distributed load  and/or concentrated  loads.      *
c *   The program traces load-deflection curve up to the peak      *
c *   load and including a portion  of the  descending branch      * 
c *   down to 20% of the peak load. The analysis  results for      *
c *   dented tubular members are valid for the range D/t less      *
c *   than 80 and dd/D less than  0.2.  The  analysis results      *
c *   for undented tubular  members  are valid for  the range      *
c *   D/t less than 96.                                            *
c *                                                                *
c *   The key feature  of the  program  includes  effects  of      *
c *   local buckling of cross section and multiple  dents with     *
c *   different directions.                                        *
c *                                                                *
c *                                    Purdue University           *
c *                                    October 29,  1989           *
c *                                                                *
c *   Version 1.0 - Mainframe Gould 1                              *
c *                 Sun Workstation                                *
c *                 8-1990, Purdue Uuiversity                      *
c *                                                                *
c *   Version 1.1 - HP-Apollo Workstation                          *
c *                 8-1992  California Dept. of Transportation     *  
c *                                                                *
c *   Version 1.2 - IBM-PC or Compatiable                          *
c *                 8-1992 California Dept. of Transportation      *
c *                                                                * 
c ******************************************************************

c   ################ MAIN PROGRAM ##################################

       implicit double precision (a-h, o-z)
       common/mats/ d, t, e, fy, tl
       common/resd1/ ires
       common/resd/  fr1, fr2
       common/dent1/ ndent(200), n, nstat
       common/dent/  detl(200), ddent(200), dbeta(200), wint(2,200)
       common/bond/ rstax, rstay, rstbx, rstby 
       common/bound/ nbond, method
       common/load1/ ip, iemax, iemay
       common/load/  eax, eay, ebx, eby, quax, quay, qubx, quby, 
     +   qcx1, qcy1, zc1, qcx2, qcy2, zc2, emax, emay, embx, emby
       common/rload/ pratio, pmin, pmax, qymin, qymax, rqxy,
     +               quymin, quymax, qrx, qry, rquxy,
     +               emxmin, emxmax, emrx, emry, redmxy
       common/capt/ py, pu, emy, emp, emu, phiy, philb
       common/mphd/ emud, empud, phipud, sd
       common/pi/ pi
       common/defm/  wxy(2,200), rotxy(2,200), wrsu(2,200),
     +               slope(2,200), phixy(2,200)
       common/dfrt/  dfint(200), dfrte(200), dfrtc(200),
     +               dfange(200), dfangc(200), dasum(200)
       common/bmom/  bmrt(200), bmag(200), dang(200), phi(200),
     +               bmxy(2,200)
       common/fact/ factor, factor1, nbuck 
       common/local/ nloca
       common/resp/ wasum(2,200), wdxy(2,200), phi1(200), emom1(200),
     +             epson(200), phimax(200)
       common/simp/  wintx, winty, bmx, bmy, bmrts, bmags, dangs, 
     +               wdx, wdy, sl, dl, beta, dd, ppmin,ppmax, dphi
       common/down/ ddw, dw1, comstop
      character  FIN*10,  FOUT*14, BLANK
      PARAMETER (BLANK = ' ')

      print*, '      BCDENT - ANALYSIS OF DENTED TUBULAR MEMBERS'
      print*, ' '
      print*, ' PLEASE ENTER YOUR DATA FILE NAME (UP TO 10 CHARATERS)'
      print*, ' '
      print*, ' YOUR OUTPUT FILE IS  DATAFILE.out'
      read (*, '(A)') FIN  
      PRINT*, FIN 
      NFIRST   = 0
      NLAST    = 0
      DO  1000  J = 1, 10
      If (FIN(J:J) .NE. BLANK) THEN
         NFIRST = NFIRST + 1
         IF (NFIRST .EQ. 1) THEN
         NCHB = J
         ENDIF
      ELSEIF ((FIN(J:J) .EQ. BLANK) .AND. (J .GE. NCHB)) THEN
         NLAST = NLAST + 1
         IF (NLAST .EQ. 1) THEN
         NCHE = J - 1
         ENDIF
      ENDIF  
1000  continue      

      FOUT = FIN(NCHB:NCHE) // '.out'
      OPEN( UNIT = 5, FILE = FIN, ACCESS = 'SEQUENTIAL',
     +      STATUS = 'OLD') 
      OPEN( UNIT = 6, FILE = FOUT, ACCESS = 'SEQUENTIAL',
     +      STATUS = 'UNKNOWN') 

        call datapt()
        call capact()
c ###### Re-determine the Dent Segments #######
        do 90  j =1, n
        if (ddent(j)/t .gt. 1.0) then
        ndent(j) = 1
        else
        ndent(j) = 0
        endif
90      continue

        if (method .eq. 1) then
c ###### Moment-Curvature Approach ##############################
c ######## Loading Cases #1  Axial Load Only ####################
        if (ip .eq. 1) call respaxd(p)

c ######## Loading Case #2 and # 3  Constant End-Moments ########
c          and Laterally Concentrated or Distributed Loads
c               Increasing  Axial Load only 
        if (ip .eq. 2 .or. ip .eq. 3) then
        p = 0.0001
        emax = emax*emp
        emay = emay*emp
        embx = embx*emp
        emby = emby*emp
        call respint(p)
        call respaxd(p)
        endif

c ######## Loading Case #4 Constant Axial load ##################
c          and Increasing Laterally Concentrated Loads
       if (ip .eq. 4) then
        p = pratio
        call respint(p)
        call respcon(p)
        endif

c ######## Loading Case #5 Constant Axial load ##################
c          and Increasing Laterally Distributed Loads
       if (ip .eq. 5) then
        p = pratio
        call respint(p)
        call respdis(p)
        endif

c ######## Loading Case #6 Constant Axial load ##################
c            and Increasing End-Moments
       if (ip .eq. 6) then
        p = pratio
        call respint(p)
        call respmed(p)
        endif
        

        endif
c ########## Approximated Simple-Hinge Approach ###################
       if (method .eq. 2) then
       call bcdents()
       endif

      CLOSE(5)
      CLOSE(6)
       
       end
c ################## MAIN PROGRAM END ##############################

c ******************************************************************
       subroutine datapt()
c ******************************************************************
c *                                                                *
c *    Subroutine datapt() is to read input data, to generate      *
c *    preliminary data and to print these data for analysis       *
c *    of dented tubular members                                   *
c *                                                                *
c ******************************************************************

       implicit double precision (a-h, o-z)
       common/mats/ d, t, e, fy, tl
       common/resd1/ ires
       common/dent1/ ndent(200), n, nstat
       common/dent/  detl(200), ddent(200), dbeta(200), wint(2,200)
       common/bond/ rstax, rstay, rstbx, rstby 
       common/bound/ nbond, method
       common/load1/ ip, iemax, iemay
       common/load/  eax, eay, ebx, eby, quax, quay, qubx, quby, 
     +   qcx1, qcy1, zc1, qcx2, qcy2, zc2, emax, emay, embx, emby
       common/rload/ pratio, pmin, pmax, qymin, qymax, rqxy,
     +               quymin, quymax, qrx, qry, rquxy,
     +               emymin, emymax, emrx, emry, redmxy
       common/capt/ py, pu, emy, emp, emu, phiy, philb
       common/simp/  wintx, winty, bmx, bmy, bmrts, bmags, dangs, 
     +               wdx, wdy, sl, dl, beta, dd, ppmin,ppmax, dphi
       common/pi/ pi
       common/down/ ddw, dw1, comstop
       common/local/ nloca

       read(5, '(3i5)')  nbond, nloca, nstat
       read(5, '(5f10.0)') d, t, e, fy, tl
       read(5, '(i5)')  ires

       if (nbond .eq. 100) write(6, 523) nbond
       if (nbond .eq. 101) write(6, 524) nbond
       if (nbond .lt. 100 .or. nbond .gt. 101) then
          write(6, 529) nbond
          stop
       endif

       if (nloca .eq. 1) write(6, 521)
       if (nloca .eq. 0) write(6, 522)
       if (nloca .gt. 1 .or. nloca .lt. 0) then
          write(6, 525) nloca
          stop
       endif

       write(6, 501) d, t, e, fy, tl, ires
       read(5,'(4f10.0)') rstax, rstay, rstbx, rstby 
       write(6, 502) rstax, rstay, rstbx, rstby

       read(5,'(i5)')  ip
       if (ip .eq. 1)   then
        read(5,'(2f10.0)')  pmin, pmax
        read(5,'(4f10.0)')  eax, eay, ebx, eby
        write(6, 503)  ip, eax, eay, ebx, eby
        write(6, 504) pmin, pmax
       endif

       if (ip .eq. 2) then
        read(5,'(2f10.0)')  pmin, pmax
        read(5,'(4f10.0)')  eax, eay, ebx, eby
        read(5,'(4f10.0)')  emax, emay, embx, emby
        read(5,'(i5)') iqc  
        if (iqc .eq. 1) read(5,'(3f10.0)')  qcx1, qcy1, zc1
        if (iqc .eq. 2) read(5,'(6f10.0)')  qcx1, qcy1, zc1, 
     +                                      qcx2, qcy2, zc2
        write(6, 505)  ip, iqc, qcx1, qcy1, zc1, qcx2, qcy2, zc2
        write (6, 506) emax, emay, embx, emby, eax, eay, ebx, eby
        write(6, 504) pmin, pmax
       endif

       if (ip .eq. 3) then
        read(5,'(2f10.0)')  pmin, pmax
        read(5,'(4f10.0)')  eax, eay, ebx, eby
        read(5,'(4f10.0)')  emax, emay, embx, emby
        read(5,'(4f10.0)')  quax, quay, qubx, quby
        write(6, 507) ip, quax, quay, qubx, quby
        write (6, 506) emax, emay, embx, emby, eax, eay, ebx, eby
        write(6, 504) pmin, pmax
       endif

       if (ip .eq. 4) then
        read(5,'(3f10.0)') pratio, zc1, zc2
        read(5,'(3f10.0)') qymin, qymax, rqxy
        write(6, 508) ip, pratio, zc1, zc2
        write(6, 509) qymin, qymax, rqxy
       endif

        if (ip .eq. 5) then
         read(5,'(3f10.0)') pratio, qrx, qry
         read(5,'(3f10.0)') quymin, quymax, rquxy
         write(6, 510) ip, pratio, qrx, qry
         write(6, 511) quymin, quymax, rquxy
        endif

        if (ip .eq. 6) then
         read(5,'(3f10.0, 2i5)') pratio, emrx, emry, iemax, iemay
         read(5,'(3f10.0)') emymin, emymax, redmxy
         write(6, 512) ip, pratio, emrx, emry, iemax, iemay
         write(6, 513) emymin, emymax, redmxy
        endif

       if (ip .lt. 1 .or. ip .gt. 6) then
        write(6, 514) ip
        stop
       endif

        read(5,'(i5)') n
        read(5,'(2f10.0)') (wint(1, j), wint(2,j), j=1, n+1)
        write(6, 515) n
        write(6, 516)
        write(6, 517) (j, wint(1,j), wint(2,j), j=1, n+1)
        read(5,'(f10.0, i10, 2f10.0)') 
     +          (detl(j), ndent(j), ddent(j), dbeta(j), j=1, n) 
        write(6, 518)
        write(6, 519) (j, detl(j), ndent(j), ddent(j), dbeta(j),
     +                 j=1, n)
        pi = 4.*atan(1.)
        do 600 j = 1, n
        dbeta(j) = dbeta(j)*pi/180.
600     continue

        read(5,'(2f10.0)') ddwr, comstop
        ddw = ddwr*tl
        dw1 = ddw
        comst = comstop*100.
        write(6, 520) nstat, ddwr, ddw, comst
        
        read(5,'(i5)') method
        if (method .eq. 1) write(6, 526)
        if (method .eq. 2) then
          read(5,'(4f10.0)') sl, dl, wintx, winty
          read(5,'(2f10.0)') beta, dd
          read(5,'(3f10.0)') ppmin, ppmax, dphi
          write(6, 527) sl, dl, wintx, winty, beta, dd, 
     +                 ppmin, ppmax, dphi
         endif

        if (method .lt. 1 .or. method .gt. 2) then
          write(6, 528) method
          stop
         endif

        if (method .eq. 2 .and. ip .gt. 3) then
          write(6, 530) method, ip
          stop
         endif

501    format(//, 5x, 'ANALYSIS  OF  DENTED  TUBULAR  MEMBER', 
     +         /, 3x,'###########################################',
     +        /,  5x, '(Valid for Range of D/t <= 80 and dd/D <= 0.2)',
     +       ///, 5x, 'INPUT DATA FOR DENTED MEMBER',
     +        //, 10x, 'Outer Diameter   D  =', f15.4, 3x, 'mm',
     +        /,  10x, 'Thickness        t  =', f15.4, 3x, 'mm',
     +        /,  10x, 'Elastic Modulus  E  =', f15.4, 3x, 'Mpa',
     +        /,  10x, 'Yield Strength   Fy =', f15.4, 3x, 'Mpa',
     +        /,  10x, 'Member Length    L  =', f15.4, 3x, 'mm',
     +        /,  10x, 'Residual Stress Indicator  ires =', i11)

502    format(/, 5x, 'Linear Rotational End-Restraint Stiffness Rst',
     +   /, 10x, ' Rsax (A-end X-X axis) =', e15.4, 3x, 'N-mm/Rad',
     +   /, 10x, ' Rsay (A-end Y-Y axis) =', e15.4, 3x, 'N-mm/Rad',
     +   /, 10x, ' Rsbx (B-end X-X axis) =', e15.4, 3x, 'N-mm/Rad',
     +   /, 10x, ' Rsby (B-end Y-Y axis) =', e15.4, 3x, 'N-mm/Rad')

503    format(//, 5x, 'Loading  Case Indicator  ip  =', i4,
     +       /, 10x, 'Axial Load Only ',
     +      //, 10x, 'Eccentricity A-end X-X   eax =', f10.3, 3x, 'mm',
     +       /, 10x, 'Eccentricity A-end Y-Y   eay =', f10.3, 3x, 'mm',
     +       /, 10x, 'Eccentricity B-end X-X   ebx =', f10.3, 3x, 'mm',
     +       /, 10x, 'Eccentricity B-end Y-Y   eby =', f10.3, 3x, 'mm')

504    format(//,5x, 'Limits of Axial Load Ratio  P/Py'
     +         /, 10x, 'Minimum Axial Load Ratio  Pmin/Py =', f10.4,
     +         /, 10x, 'Maximum Axial Load Ratio  Pmax/Py =', f10.4)

505    format(//, 5x, 'Loading  Case Indicator  ip =', i4,
     +      /,10x, 'Constant End Moments and Lateral Concentrated Load'
     +      /,10x, 'Increasing Axial Load Only',
     +     //, 5x, 'Number of Concentrated Loads  iqc  =', i4,
     +      /, 10x, 'Load #1 (X-X axis)   qcx1 =', e15.4, 3x, 'N',
     +      /, 10x, 'Load #1 (Y-Y axis)   qcy1 =', e15.4, 3x, 'N',
     +      /, 10x, 'Distance from A-end   zc1 =', f15.4, 3x, 'mm',
     +      /, 10x, 'Load #2 (X-X axis)   qcx2 =', e15.4, 3x, 'N',
     +      /, 10x, 'Load #2 (Y-Y axis)   qcy2 =', e15.4, 3x, 'N',
     +      /, 10x, 'Distance from A-end   zc2 =', f15.4, 3x, 'mm')

506    format(//, 5x, 'End-Moment Ratio Mend/Mp',
     +    /, 10x,'A-End Moment (X-X axis) Max/Mp =', f10.4,
     +    /, 10x, 'A-End Moment (Y-Y axis) May/Mp =', f10.4,
     +    /, 10x, 'B-End Moment (X-X axis) Mbx/Mp =', f10.4,
     +    /, 10x, 'B-End Moment (Y-Y axis) Mby/Mp =', f10.4,
     +    //, 5x, 'Axial Load Eccentricities',
     +    /, 10x, 'Eccentricity A-end X-X   eax =', f10.3, 3x, 'mm',
     +    /, 10x, 'Eccentricity A-end Y-Y   eay =', f10.3, 3x, 'mm',
     +    /, 10x, 'Eccentricity B-end X-X   ebx =', f10.3, 3x, 'mm',
     +    /, 10x, 'Eccentricity B-end Y-Y   eby =', f10.3, 3x, 'mm')

507    format(//, 5x, 'Loading  Case Indicator  ip =', i4,
     +     /, 10x, 'Constant End Moments and Lateral Distributed Load'
     +     /, 10x, 'Increasing Axial Load Only', 
     +    //, 10x, 'A-End Load (X-X axis)  quax =', e15.4, 3x, 'N/mm' 
     +     /, 10x, 'A-End Load (Y-Y axis)  quay =', e15.4, 3x, 'N/mm' 
     +     /, 10x, 'B-End Load (X-X axis)  qubx =', e15.4, 3x, 'N/mm' 
     +     /, 10x, 'B-End Load (Y-Y axis)  quby =', e15.4, 3x, 'N/mm')

508    format(//, 5x, 'Loading  Case Indicator  ip =', i4,
     +     /, 10x,  'Constant Axial Load  Ratio  P/Py =', f15.4,
     +     /, 10x, 'Increasing Lateral Concentrated Loads', 
     + //, 10x, 'Load #1 - Distance from A-end   zc1 =', f15.4,3x, 'mm',
     +  /, 10x, 'Load #2 - Distance from A-end   zc2 =', f15.4,3x, 'mm')

509    format(//,5x, 'Limits of Lateral Concentrated Load',
     +         /, 10x, 'Qymin (Y-Y axis)   = ',  e15.4, 3x, 'N',
     +         /, 10x, 'Qymax (Y-Y axis)   = ',  e15.4, 3x, 'N',
     +         /, 10x, 'Load Ratio Qx/Qy   = ',  e15.4)

510     format(//, 5x, 'Loading  Case Indicator  ip =', i4,
     +     /, 10x,  'Constant Axial Load  Ratio  P/Py =', f15.4,
     +     /, 10x, 'Increasing Lateral Distributed  Loads', 
     + //, 10x, 'End-Distributed Load Ratio (X-X axis)  qrx =', f15.4,
     +  /, 10x, 'End-Distributed Load Ratio (Y-Y axis)  qry =', f15.4)

511    format(//,5x, 'Limits of Distributed Load',
     +         /, 10x, 'Quymin (Y-Y axis)   = ',  e15.4, 3x, 'N/mm',
     +         /, 10x, 'Quymax (Y-Y axis)   = ',  e15.4, 3x, 'N/mm',
     +         /, 10x, 'Load Ratio Qux/Quy  = ',  e15.4)
    
512     format(//, 5x, 'Loading  Case Indicator  ip =', i4,
     +     /,10x,  'Constant Axial Load  Ratio  P/Py =', f15.4,
     +     /,10x, 'Increasing End-Moments ', 
     +    //,10x, 'End-Moments  Ratio (X-X axis)  Mb/Ma =', f15.4,
     +     /,10x, 'End-Moments  Ratio (Y-Y axis)  Mb/Ma =', f15.4,
     +     /,10x, 'A-End Moment Direction (X-X axis)  iemax =', i4
     +     /,10x, 'A-End Moment Direction (Y-Y axis)  iemay =', i4)


513    format(//,5x, 'Limits of End-Moment Ratio M/Mp',
     +         /, 10x, 'Mymin/Mp (Y-Y axis)   = ',  f10.4,
     +         /, 10x, 'Mymax/Mp (Y-Y axis)   = ',  f10.4,
     +         /, 10x, 'Moment Ratio Max/May  = ',  f10.4)

514     format(//, 5x, 'Load Case Indicator  ip  = ', i4, 
     +       //, 5x, 'Please Check Your Input of Load Case Indicator', 
     +       //,  'NOTE THAT Loading  Case Indicator Only Can Be ',
     +  /,5x,'1 --- Axial Load Only',
     +  /,5x,'2 --- Constant End-Moments and Lateral Concentrated Load',
     +  /,5x,'      Increasing Axial Load Only',
     +  /,5x,'3 --- Constant End-Moments and Lateral Distributed Load',
     +  /,5x,'      Increasing Axial Load Only',
     +  /,5x,'4 --- Constant Axial Load ',
     +  /, 5x,'      Increasing Lateral Concentrated Loads',
     +  /, 5x, '5 --- Constant Axial Load ',
     +  /, 5x, '      Increasing Lateral Distributed Loads',
     +  /, 5x, '6 --- Constant Axial Load ',
     +  /, 5x, '      Increasing End-Moments ',
     +        /,  'Please Try Again!')

515     format(/, 5x, 'Number of Segments    n =', i4, //)

516     format(/,10x,  '   INITIAL  DEFLECTIONS '
     +        //, 2x,'Stations', 6x, 'Wint (X-X)', 8x, 'Wint (Y-Y)',
     +         /, 14x,               '   (mm)  ', 10x, '   (mm)')
517     format(/, 3x, i4, 5x, f10.4, 9x, f10.4)

518     format(//, 15x, ' DENT  INFORMATION',
     +   //, 2x, 'Segments',3x,'Delta', 5x,'Dent',7x,'Dent',7x, 'Dent',
     +   /,  12x, 'Length', 4x, 'Indicator', 2x,' Depth ', 5x,'Angle',
     +   /,  12x, ' (mm) ', 17x,               '(mm)', 4x, '(degree)',)

519      format(/, 3x, i4, f12.3, 3x,  i4, 2f12.3)

520      format(//, 5x, 'Controlling Parameters',
     +   /, 10x, 'Controlling Station Number   Nstat  =', i10,
     +   /, 10x, 'Deflection Incremental Ratio Dw/L   =', f15.4,
     +   /, 10x, 'Deflection Incremental       Dw     =', f15.4,3x,'mm',
     +   //,5x, 'Your Computation Will Stop Until The Load Down to ',
     +   f4.1, '% Peak Load')

521      format(//, 5x, 'Local Buckling Considered in M-P-PHI Curves',
     +           /, 5x, '         For Undented Sections')
522      format(//, 5x, 'Local Buckling  Not  Considered in M-P-PHI',
     +           /, 5x, '     Curves  For Undented Sections')

523      format(//, 5x, 'Boundary Indicator =', i4,
     +          /, 5x, 'Analyzed Member is Simply Supported ',
     +          /,  5x, 'Or Elastic-Rotational Restrainted')
524      format(//, 5x, 'Boundary Indicator =', i4,
     +       //, 5x, 'Analyzed Member is Cantilever with Free-A-End')

525     format(//, 5x, 'Local Buckling Indicator  nloca   = ', i4, 
     +  //, 5x, 'Please Check Your Input of Local Buckling Indicator',
     +  //,  'NOTE THAT Local Buckling Indicator Only Can Be ',
     +  /,5x,'1 --- Local Buckling Considered ',
     +  /,5x,'0 --- Local Buckling Not Considered',
     +  /,  'Please Try Again!')
526      format(//, 5x, 'Moment-Curvature Integration Approach is Used',
     +          /, 5x,  'in the Analysis')
527      format(//, 5x, 'Simple Plastic-Hinge  Approach is Used',
     +          /, 5x,  'in the Analysis',
     +          /, 7x,  '    (Approximated Estimation)',
     +         //, 5x, 'Controlling Parameters',
     +   /, 10x, 'Distance of Critical Section   L1  =',f15.4,3x,'mm',
     +   /, 10x, 'Length of Critical Segment    DL   =',f15.4,3x,'mm',
     +   /, 10x, 'Initial Deflection (X-X)     Wintx =',f15.4,3x,'mm',
     +   /, 10x, 'Initial Deflection (Y-Y)     Winty =',f15.4,3x,'mm',
     +   /, 10x, 'Dent Angle Respect to X-X     Beta =',f15.3,3x,
     +     'Degree',
     +   /, 10x, 'Dent Depth                     dd  =', f15.3,3x,'mm',
     +   //,10x, 'Minimum Axial Load Ratio   Pmin/Py =', f10.4,
     +   /, 10x, 'Maximum Axial Load Ratio   Pmax/Py =', f10.4,
     +  /,10x, 'Curvature Incremental    dPhi/Phiy =',f10.4,3x,'Rad/mm')

528     format(//, 5x, 'Analysis Method Indicator    = ', i4, 
     +       //, 5x, 'Please Check Your Input for Method Indicator'
     +       //,  'NOTE THAT Method Indicator Only Can Be ',
     +  /,5x,'1 --- More Accurate Moment-Curvature Approach',
     +  /,5x,'2 --- Approximated Simple Plastic-Hinge Approach',
     +        /,  'Please Try Again!')

529     format(//, 5x, 'Boundary Indicator =', i4,
     +  //, 5x, 'Please Check Your Input for Boundary Indicator',
     +  //,  'NOTE THAT Boundary Indicator Only Can Be ',
     +  /,5x,'100 --- Simply Supported or',
     +  /,5x, '       Elastic-Rationally Restrainted',
     +  /,5x,'101 --- Cantilever with Free-A-End',
     +  /,5x,'Please Try Again!')

530     format(//, 5x, 'Boundary Indicator =', i4,
     +  /, 5x, 'Loading  Indicator =', i4,
     +  //, 5x, 'Please Check Your Input for Loading Indicator',
     +  //,  'NOTE THAT In Simple Plastic-Hinge Approach',
     +  /, 5x, 'Loading Indicator Only Can Be ',
     +  /,5x,'1, 2 and 3 --- for Increasing Axial Load Only',
     +  /,5x,'Please Try Again!')

        return
        end

c *****************************************************************
      subroutine capact()
c ******************************************************************
c *                                                                *
c *    Subroutine capact( ) is  to determine the  sectional        *
c *    load-carrying capacity of undented tubular sections         *
c *    including the effects of local buckling   (based on         *
c *    API-2A specification).                                      *
c *                                                                *
c *                                                                *
c * Variables:                                                     *
c *   py  = axial yield strength                                   *
c *   pu  = compression yield strength normalized by Py            *
c *   emy = initial yield moment                                   *
c *   emp = plastic moment                                         *
c *   emu = moment capacity normalized by Mp                       *
c *   phiy= initial yield curvature                                *
c *                                                                *
c ******************************************************************

      implicit double precision (a-h, o-z)
      common/mats/ d, t, e, fy, tl
      common/capt/ py, pu, emy, emp, emu, phiy, philb
      common/pi/ pi

c ##### Calculate Axial Yield Strength #####
        py  = fy*(d - t)*pi*t 
        dtt = d/t
        if (dtt .le. 100.) then
         pu = 1.0
        else
         pu = 1.95 - 0.3*(dtt)**0.25
        endif
         pu = pu*py
c ##### Calculate Moment Capacity #####
c       (SI- System)

        emy = pi*fy*t*(d - t)*(d - t)/4.
        emp = fy*t*(d - t)*(d - t)
        fydt = fy*d/t
        if (fydt .le.  17240.) then
         emu = 1.
        elseif ((fydt . gt. 17240.) .and. (fydt .le. 44820.)) then
         emu = 1.13 - 1.54*fydt/e
        elseif ((fydt .gt. 44820.) .and. (fydt .le. 137900.)) then
         emu = 0.96 - 0.77*fydt/e
        endif
        emu = emu*emp

c ##### Calculate Moment Capacity #####
c       (IN-POUND System)

c       emy = pi*fy*t*(d - t)*(d - t)/4.
c       emp = fy*t*(d - t)*(d - t)
c       fydt = fy*d/t
c       if (fydt .le.  2500.) then
c        emu = 1.
c       elseif ((fydt . gt. 2500.) .and. (fydt .le. 6500.)) then
c        emu = 1.13 - 1.54*fydt/e
c       elseif ((fydt .gt. 6500.) .and. (fydt .le. 20000.)) then
c        emu = 0.96 - 0.77*fydt/e
c       endif
c       emu = emu*emp

c ##### Calculate Sectional Properties ######
        ta = pi*(d - t)*t
        ddt = (d - 2.*t)/d
        ei  = pi*d*d*d*d*(1. - ddt*ddt*ddt*ddt)/64.
        eri = d*sqrt(1. + ddt*ddt)/4.
        ek  = tl/eri
c ##### Calculate Yield Curvature #####
        phiy = 2*fy/(e*d)
        write(6, 522)  ta, ei, eri, ek
522     format(//, 5x, ' Sectional Properties',
     + //,  10x, 'Cross-section Area   A  =', e15.4, 3x, 'mm2',
     + //,  10x, 'Moment of inertia    I  =', e15.4, 3x,  'mm4',
     + //, 10x, 'Radius of Gyration   r  =', f15.4, 3x, 'mm',
     + //, 10x, 'Slenderness Ratio  L/r  =', f15.4)
         pye = py*1.d-3
         pue = pu*1.d-3
         emye = emy*1.d-6
         empe = emp*1.d-6
         emue = emu*1.d-6
         write(6, 523)  pye, pue, emye, empe, emue, phiy
523      format(//, 5x, 'Undented  Sectional Load-Carrying Capacities',
     + //, 10x, 'Axial Yield Strength     Py =', e15.4, 3x, 'KN',
     + //, 10x, 'Axial Ultimate Strength  Pu =', e15.4, 3x, 'KN',
     + //, 10x, 'Yield Moment             My =', e15.4, 3x, 'KN-m',
     + //, 10x, 'Plastic Moment           Mp =', e15.4, 3x, 'KN-m',
     + //, 10x, 'Ultimate Moment          Mu =', e15.4, 3x, 'KN-m',
     + //, 10x, 'Yield Curvature        Phiy =', e15.8, 3x, 'Rad/mm')

       return
       end


c ******************************************************************
       subroutine respint(p)
c ******************************************************************
c *    Subroutine respint(p) is to compute initial response for    * 
c *    constant axial loads, or constant end-moments, or lateral   * 
c *    loads                                                       *
c *                                                                *
c ******************************************************************

       implicit double precision (a-h, o-z)
       common/mats/ d, t, e, fy, tl
       common/resd1/ ires
       common/resd/  fr1, fr2
       common/dent1/ ndent(200), n, nstat
       common/dent/  detl(200), ddent(200), dbeta(200), wint(2,200)
       common/bond/ rstax, rstay, rstbx, rstby
       common/bound/ nbond, method
       common/load1/ ip, iemax, iemay
       common/load/  eax, eay, ebx, eby, quax, quay, qubx, quby, 
     +   qcx1, qcy1, zc1, qcx2, qcy2, zc2, emax, emay, embx, emby
       common/rload/ pratio, pmin, pmax, qymin, qymax, rqxy,
     +               quymin, quymax, qrx, qry, rquxy,
     +               emxmin, emxmax, emrx, emry, redmxy
       common/capt/ py, pu, emy, emp, emu, phiy, philb
       common/mphd/ emud, empud, phipud, sd
       common/pi/ pi
       common/defm/  wxy(2,200), rotxy(2,200), wrsu(2,200),
     +               slope(2,200), phixy(2,200)
       common/dfrt/  dfint(200), dfrte(200), dfrtc(200),
     +               dfange(200), dfangc(200), dasum(200)
       common/bmom/  bmrt(200), bmag(200), dang(200), phi(200),
     +               bmxy(2,200)
       common/fact/ factor, factor1, nbuck 
       common/local/ nloca
       common/resp/ wasum(2,200), wdxy(2,200), phi1(200), emom1(200),
     +             epson(200), phimax(200)
c      common/down/ ddw, dw1, comstop

c ###### First assume deflection #####

c      (Assume  First Step Deflections)
        call defang(wint, dfange, dfint, n)
        dasum(nstat) = ddw
        dratio = ddw/dfint(nstat)
        do 100 j = 1, n+1
        dasum(j) = dratio*dfint(j)
        wxy(1,j) = dasum(j)*dcos(dfange(j))
        wxy(2,j) = dasum(j)*dsin(dfange(j))
100     continue

c ####### Determine Deflection Due to Constant Loads #####


200     call bedm(p)
        call phimbr(phi1, emom1, phimax, p)

        do 120 j=1, n+1
        phixy(2,j) = phi(j)*cos(bmag(j))
        phixy(1,j) = phi(j)*sin(bmag(j))
120     continue
        call newmark()
        call defang(wrsu, dfangc, dfrtc, n)
       
c #####  Check accuracy of deflections ######
        niter = niter + 1


        do 140 j = 2, n
        der2 = (dasum(j) - dfrtc(j))/dfrtc(j)
        if ( abs(der2) .gt. 0.001) then
          do 130 jj = 1, n
          dasum(jj) = dfrtc(jj)
          wxy(1,jj) = dasum(jj)*dcos(dfangc(jj))
130       wxy(2,jj) = dasum(jj)*dsin(dfangc(jj))

          go to 200
         endif
140      continue
         do 150 jj = 1, n+1
         wdxy(1,jj) = wrsu(1,jj) + wint(1,jj) 
150      wdxy(2,jj) = wrsu(2,jj) + wint(2,jj)

       write(6, 51) niter, der1, p, p*py
51     format(/,5x, 'Iteration Number =', i6, /,
     +        5x, 'Relative  Error  =', e14.4, /,
     +        5x, 'Axial Load Ratio =', f10.4, /,
     +        5x, 'Axial Load       =', e14.4, 2x, 'N')
        
       call shorten(pc, p)

       write(6, 52) 
52     format(2x,'Station',2x,'Mom-X',5x,'Def-Y',4x,'Slope-X',
     +    6x,'Mom-Y',5x,  'Def-X',4x,'Slope-Y',/,
     +    10x, '(Mx/Mp)',5x,'(mm)',4x,'(Rad)',7x,'(My/Mp)',
     +    4x, '(mm)', 6x, '(Rad)')
       write(6, 55) (j,  bmxy(1,j), wdxy(2,j), slope(2,j), bmxy(2,j),
     +               wdxy(1,j), slope(1,j),  j=1, n+1)

55    format(/, i6, 2f10.3,  e12.3, 2f10.3, e12.3)
        do 178 j = 1, n+1
        emom1(j) = bmrt(j) 

178     phi1(j) = phi(j)

        return
        end



c ******************************************************************
       subroutine respaxd(p)
c ******************************************************************
c *    Subroutine respaxd(p) is to compute deformation response    *
c *    for increasing axial load  only                             *
c *                                                                *
c ******************************************************************

       implicit double precision (a-h, o-z)
       common/mats/ d, t, e, fy, tl
       common/resd1/ ires
       common/resd/  fr1, fr2
       common/dent1/ ndent(200), n, nstat
       common/dent/  detl(200), ddent(200), dbeta(200), wint(2,200)
       common/bond/ rstax, rstay, rstbx, rstby 
       common/bound/ nbond, method
       common/load1/ ip, iemax, iemay
       common/load/  eax, eay, ebx, eby, quax, quay, qubx, quby, 
     +   qcx1, qcy1, zc1, qcx2, qcy2, zc2, emax, emay, embx, emby
       common/rload/ pratio, pmin, pmax, qymin, qymax, rqxy,
     +               quymin, quymax, qrx, qry, rquxy,
     +               emxmin, emxmax, emrx, emry, redmxy
       common/capt/ py, pu, emy, emp, emu, phiy, philb
       common/mphd/ emud, empud, phipud, sd
       common/pi/ pi
       common/defm/  wxy(2,200), rotxy(2,200), wrsu(2,200),
     +               slope(2,200), phixy(2,200)
       common/dfrt/  dfint(200), dfrte(200), dfrtc(200),
     +               dfange(200), dfangc(200), dasum(200)
       common/bmom/  bmrt(200), bmag(200), dang(200), phi(200),
     +               bmxy(2,200)
       common/fact/ factor, factor1, nbuck 
       common/local/ nloca
       common/resp/ wasum(2,200), wdxy(2,200), phi1(200), emom1(200),
     +             epson(200), phimax(200)
       common/down/ ddw, dw1, comstop

c##### Calculate Axial Load Response  ######

c      (Assume  First Step Deflections)
       if (ip .eq. 1) then
        call defang(wint, dfange, dfint, n)
        dasum(nstat) = ddw
        dratio = ddw/dfint(nstat)
        do 100 j = 1, n+1
        dasum(j) = dratio*dfint(j)
        wxy(1,j) = dasum(j)*dcos(dfange(j))
        wxy(2,j) = dasum(j)*dsin(dfange(j))
100     continue
        call defang(wint, dfange, dfrte, n)
        wdf = dfint(nstat)
       else

        call defang(wdxy, dfange, dfrte, n)
        dratio = ddw/(dfrte(nstat) - dfint(nstat))
        do 101 j = 1, n+1
        dasum(j) = dfrte(j) - dfint(j) + dratio*(dfrte(j) - dfint(j))
        wxy(1,j) = dasum(j)*dcos(dfange(j))
        wxy(2,j) = dasum(j)*dsin(dfange(j))
 101     continue
        wdf = dfrte(nstat)
       endif

        pp1 = 0.0
        pp2 = 0.0
        np  = 0
        nbuck = 0

        do 900  m = 1, 10000
        nnter = 0
        niter   = 0
        factor = 1.
        factor1 = factor
        psta =  pmin
        pend =   pmax
299     if (pp1 .lt. pp2) then 
          np = np + 1
          pend = pp1
        endif

        if (np .eq. 1) then
          peak = pp2
          print*, 'Peak Axial Load    P =', peak*py, '  N'
          write(6,304) peak*py
304       format(5x, 'Peak Axial Load P = ', f15.3, 2x, 'N')
         endif
        pp2 = pp1
c #####  Determine axial load   #######
        pstap = psta
        pendp = pend
305     p1 = psta + (pend - psta)*0.658
        p  = p1

205     factor1 = 1.0
        factor = 1.0
        call bedm(p)
        call phimbs(phi1, emom1, phimax, p)

        fact = 1.0
        nbuck = 0
        if (factor1 .lt. fact)  then
           p   = p*factor1
           factor1 = 1.0
          go to 205
        endif

        do 125 j=1, n+1
        phixy(2,j) = phi(j)*cos(bmag(j))
        phixy(1,j) = phi(j)*sin(bmag(j))
125     continue
        call newmark()
        call defang(wrsu, dfangc, dfrtc, n)

c #####  Check accuracy of deflections ######
        niter = niter + 1

c##### Interrupt! Iteration More than 500 Times ########

        call intrup1(nnter)
c#############################################################
        
        if (niter .gt. 50) then
        nnter = nnter + 1
        ddww = 0.5*dw1
        dasum(nstat) = dfrte(nstat) - dfint(nstat) + ddww
        dratio = ddww/(dfrte(nstat) - dfint(nstat))
        do 165 j = 1, n+1
        dasum(j) = dfrte(j) - dfint(j) + dratio*(dfrte(j) - dfint(j))
        wxy(1,j) = dasum(j)*dcos(dfange(j))
        wxy(2,j) = dasum(j)*dsin(dfange(j))
165     continue
        
        niter = 0
        dw1 = ddww
        psta = pstap
        go to 305
        endif

c #### Determine the curvature ratio for every stations #######

        phira = 0.0
        do 314 j = 1, n+1
        phirat = phi1(j)/phimax(j)
        if (phirat .gt. phira) phira = phirat
314     continue

        dero = dasum(nstat) - dfrtc(nstat)
        der1 = dero/dfrtc(nstat)

        if (phira  .lt. 0.99) then
        if ( abs(der1) .gt. 0.001 ) then
          if ( dero .gt. 0.)  then
           psta  = p
          else
           pend= p
          endif
          go to 305
        endif
       else

        nbuck = 1
        if ( abs(der1) .gt. 0.001 ) then
          if ( dero .gt. 0.)  then
           pend  = p
           psta = pstap
          else
           psta = p
           pend = pendp
          endif
          go to 305
        endif
        endif

        psta = pstap
        pend = pendp

        do 145 j = 2, n
        der2 = (dasum(j) - dfrtc(j))/dfrtc(j)
        if ( abs(der2) .gt. 0.001) then
          do 136 jj = 2, n
          dasum(jj) = dfrtc(jj)
          wxy(1,jj) = dasum(jj)*dcos(dfangc(jj))
136       wxy(2,jj) = dasum(jj)*dsin(dfangc(jj))

          go to 205
         endif
145      continue
         do 155 jj = 1, n+1
         wdxy(1,jj) = wrsu(1,jj) + wint(1,jj) 
155      wdxy(2,jj) = wrsu(2,jj) + wint(2,jj)
         call defang(wdxy, dfange, dfrte, n)

         num = niter + nnter*50
       write(6, 51) niter, der1, p, p*py
51     format(/,5x, 'Iteration Number =', i6, /,
     +        5x, 'Relative  Error  =', e14.4, /,
     +        5x, 'Axial Load Ratio =', f10.4, /,
     +        5x, 'Axial Load       =', e14.4, 2x, 'N')

         call shorten(pc, p)
       write(6, 52) 
52     format(2x,'Station',2x,'Mom-X',5x,'Def-Y',4x,'Slope-X',
     +    6x,'Mom-Y',5x,  'Def-X',4x,'Slope-Y',/,
     +    10x, '(Mx/Mp)',5x,'(mm)',4x,'(Rad)',7x,'(My/Mp)',
     +    4x, '(mm)', 6x, '(Rad)')
       write(6, 55) (j,  bmxy(1,j), wdxy(2,j), slope(2,j), bmxy(2,j),
     +               wdxy(1,j), slope(1,j),  j=1, n+1)

55    format(/, i6, 2f10.3,  e12.3, 2f10.3, e12.3)
c##############################################
         call intrup2(dfrte(nstat), wdf)
         wdf = dfrte(nstat)

c  ####### Assume next deflections #######
        dasum(nstat) = dfrte(nstat) - dfint(nstat) + ddw
        dratio = ddw/(dfrte(nstat) - dfint(nstat))
        do 160 j = 1, n+1
        dasum(j) = dfrte(j) - dfint(j) + dratio*(dfrte(j) - dfint(j))
        wxy(1,j) = dasum(j)*dcos(dfange(j))
        wxy(2,j) = dasum(j)*dsin(dfange(j))
 160     continue
        do 170 j = 1, n
        emom1(j) = bmrt(j) 
170     phi1(j) = phi(j)

        pc  = p 
        pp1 = p
        dw1 = ddw

        if (p .lt. (comstop*peak)) then
        comst = comstop*100.
        write(6, 58) comst
58      format(//,10x, 'Axial Load Less Than ', f4.1, '% Peak Load',
     +    //, 10x, 'Computation Finish, Thank you for your effort',
     +    //, 10x, 'Good Bye!')

        stop
        endif

900     continue
        return
        end



c ******************************************************************
       subroutine respcon(p)
c ******************************************************************
c *    Subroutine respcon(p) is to compute deformation response    *
c *    for increasing laterally concentrated load  only            *
c *                                                                *
c ******************************************************************

       implicit double precision (a-h, o-z)
       common/mats/ d, t, e, fy, tl
       common/resd1/ ires
       common/resd/  fr1, fr2
       common/dent1/ ndent(200), n, nstat
       common/dent/  detl(200), ddent(200), dbeta(200), wint(2,200)
       common/bond/ rstax, rstay, rstbx, rstby 
       common/bound/ nbond, method
       common/load1/ ip, iemax, iemay
       common/load/  eax, eay, ebx, eby, quax, quay, qubx, quby, 
     +   qcx1, qcy1, zc1, qcx2, qcy2, zc2, emax, emay, embx, emby
       common/rload/ pratio, pmin, pmax, qymin, qymax, rqxy,
     +               quymin, quymax, qrx, qry, rquxy,
     +               emxmin, emxmax, emrx, emry, redmxy
       common/capt/ py, pu, emy, emp, emu, phiy, philb
       common/mphd/ emud, empud, phipud, sd
       common/pi/ pi
       common/defm/  wxy(2,200), rotxy(2,200), wrsu(2,200),
     +               slope(2,200), phixy(2,200)
       common/dfrt/  dfint(200), dfrte(200), dfrtc(200),
     +               dfange(200), dfangc(200), dasum(200)
       common/bmom/  bmrt(200), bmag(200), dang(200), phi(200),
     +               bmxy(2,200)
       common/fact/ factor, factor1, nbuck 
       common/local/ nloca
       common/resp/ wasum(2,200), wdxy(2,200), phi1(200), emom1(200),
     +             epson(200), phimax(200)
       common/down/ ddw, dw1, comstop

        if (wint(2, nstat) .lt. 0. .and. wint(1, nstat) .eq. 0.0) then

c      (Assume Y-Y direction) 
        wasum(2, nstat) = ddw + wrsu(2, nstat)
        wxy(2, nstat) = wasum(2, nstat)
        dratio = ddw/wrsu(2, nstat)
        do 102  j = 1, n+1
        wasum(2,j) = wrsu(2, j) + dratio*wrsu(2,j)
 102     wxy(2,j) = wasum(2,j)
        wdf = wdxy(2, nstat)
        else
        
c      (Assume  First Step Deflections)
        call defang(wdxy, dfange, dfrte, n)
        dratio = ddw/(dfrte(nstat) - dfint(nstat))
        do 101 j = 1, n+1
        dasum(j) = dfrte(j) - dfint(j) + dratio*(dfrte(j) - dfint(j))
        wxy(1,j) = dasum(j)*dcos(dfange(j))
        wxy(2,j) = dasum(j)*dsin(dfange(j))
101     continue
        wdf = dfrte(nstat)
        endif

        qp1 = 0.0
        qp2 = 0.0
        np  = 0
        nbuck = 0
        do 900  m = 1, 12000
        niter   = 0
        nnter   = 0
        factor = 1.
        factor1 = factor
        qsta =  qymin
        qend =   qymax
        
299     if (qp1 .lt. qp2) then 
          np = np + 1
          qend = qp1
        endif

        if (np .eq. 1) then
          qpeak = qp2
          print*, 'Peak Concentrated  Load   Qy =', qp2, ' N'
          write(6,304) qp2
304       format(5x,'Peak Consentrated Load  Qy =', f15.3, 2x, 'N')
         endif

        qp2 = qp1
c #####  Determine Concentrated Loads    #######
        qstap = qsta
        qendp = qend
305     q1 =  qsta + (qend - qsta )*0.658
205     qcy1   = q1
        qcy2   = q1
        qcx1   = rqxy*q1
        qcx2   = rqxy*q1

        factor = 1.0
        factor1 = 1.0
        call bedm(p)
        call phimbs(phi1, emom1, phimax, p)
         
        fact  = 0.999999999999999
        if (factor1 .lt. fact)  then
           q1  = q1*factor1
           factor1 = 1.0
          go to 205
        endif


        do 125 j=1, n+1
        phixy(2,j) = phi(j)*cos(bmag(j))
        phixy(1,j) = phi(j)*sin(bmag(j))
        if (phicu .lt. phi(j)) phicu = phi(j)
125     continue
        call newmark()
        call defang(wrsu, dfangc, dfrtc, n)

c #####  Check accuracy of deflections ######
        niter = niter + 1

c##### Interrupt! Iteration More than 500 Times ########
        call intrup1(nnter)
c#############################################################
        
        if (niter .gt. 50) then
        nnter = nnter + 1
        ddww = 0.5*dw1
   
        if (wint(2, nstat) .lt. 0. .and. wint(1, nstat) .eq. 0.0) then
        wasum(2, nstat) = wdxy(2, nstat) - wint(2, nstat) + ddww
        dratio = ddww/(wdxy(2, nstat) - wint(2, nstat))
        do 166  j = 1, n+1
        wasum(2,j) = wdxy(2,j) - wint(2, j)  + dratio*
     +               (wdxy(2,j) - wint(2,j))
 166     wxy(2,j) = wasum(2,j)
        else

        dasum(nstat) = dfrte(nstat) - dfint(nstat) + ddww
        dratio = ddww/(dfrte(nstat) - dfint(nstat))
        do 165 j = 1, n+1
        dasum(j) = dfrte(j) - dfint(j) + dratio*(dfrte(j) - dfint(j))
        wxy(1,j) = dasum(j)*dcos(dfange(j))
        wxy(2,j) = dasum(j)*dsin(dfange(j))
165     continue
        endif
        niter = 0
        dw1 = ddww
        qsta = qstap
        go to 305
        endif

c ######## Determine the curvature ratio for every stations ######
           phira = 0.0
           do 314 j = 1, n+1
           phirat = phi1(j)/phimax(j)
           if (phirat .gt. phira) phira = phirat
314        continue

        if (wint(2, nstat) .lt. 0. .and. wint(1, nstat) .eq. 0.0) then
        dero = wasum(2, nstat) - wrsu(2, nstat)
        der1 = dero/wrsu(2,nstat)
        else
        dero = dasum(nstat) - dfrtc(nstat)
        der1 = dero/dfrtc(nstat)
        endif
        if (phira .lt. 0.99) then
        if ( abs(der1) .gt. 0.001 ) then
          if ( dero .gt. 0.)  then
           qsta  = q1
          else
           qend= q1
          endif
          go to 305
         endif
       else

         nbuck = 1 + nbuck

         if ( abs(der1) .gt. 0.01 ) then
          if ( dero .gt. 0.)  then
           qend  = q1
          else
           qsta= q1
          endif
          goto 305
          endif
          endif

144     qsta = qstap
        qend = qendp

        if (wint(2, nstat) .lt. 0. .and. wint(1, nstat) .eq. 0.0) then
        do 146 j = 2, n
        der2 = (wasum(2,j) - wrsu(2,j))/wrsu(2,j)
        if ( abs(der2) .gt. 0.01) then
          do 137 jj = 1, n
         wasum(2,jj) = wrsu(2,jj)
 137         wxy(2,jj) = wasum(2,jj)
          go to 205
         endif
 146      continue
        else
        do 145 j = 2, n
        der2 = (dasum(j) - dfrtc(j))/dfrtc(j)
        if ( abs(der2) .gt. 0.001) then
          do 136 jj = 2, n
          dasum(jj) = dfrtc(jj)
          wxy(1,jj) = dasum(jj)*dcos(dfangc(jj))
136       wxy(2,jj) = dasum(jj)*dsin(dfangc(jj))

          go to 205
         endif
145      continue
         endif

         do 155 jj = 1, n+1
         wdxy(1,jj) = wrsu(1,jj) + wint(1,jj) 
155      wdxy(2,jj) = wrsu(2,jj) + wint(2,jj)
         call defang(wdxy, dfange, dfrte, n)

         num = niter + nnter*50
       write(6, 51) num, der1, p, p*py, qcy1, qcx1
51     format(/,5x, 'Iteration Number =', i6, /,
     +        5x, 'Relative  Error  =', e14.4, /,
     +        5x, 'Axial Load Ratio =', f10.4, /,
     +        5x, 'Axial Load       =', e14.4, 2x, 'N', /,
     +        5x, 'Concentrated Load Qy =', e14.4, 2x, 'N', /,
     +        5x, 'Concentrated Load Qx =', e14.4, 2x, 'N')
         pc = p
         call shorten(pc, p)

       write(6, 52) 
52     format(2x,'Station',2x,'Mom-X',5x,'Def-Y',4x,'Slope-X',
     +    6x,'Mom-Y',5x,  'Def-X',4x,'Slope-Y',/,
     +    10x, '(Mx/Mp)',5x,'(mm)',4x,'(Rad)',7x,'(My/Mp)',
     +    4x, '(mm)', 6x, '(Rad)')
       write(6, 55) (j,  bmxy(1,j), wdxy(2,j), slope(2,j), bmxy(2,j),
     +               wdxy(1,j), slope(1,j),  j=1, n+1)

55    format(/, i6, 2f10.3,  e12.3, 2f10.3, e12.3)
c ############################################################
        if (wint(2, nstat) .lt. 0. .and. wint(1, nstat) .eq. 0.0) then
        call intrup2(wdxy(2, nstat), wdf)
        wdf = wdxy(2, nstat)
        else
        call intrup2(dfrte(nstat), wdf)
        wdf = dfrte(nstat)
        endif
c ############################################################
         
        if (wint(2, nstat) .lt. 0. .and. wint(1, nstat) .eq. 0.0) then
        wasum(2, nstat) = wrsu(2, nstat) + ddw
        dratio = ddw/wrsu(2, nstat)
        do 161  j = 1, n+1
        wasum(2,j) = wrsu(2,j) + dratio*wrsu(2,j)
 161     wxy(2,j) = wasum(2,j)
        else
        dasum(nstat) = dfrte(nstat) - dfint(nstat) + ddw
        dratio = ddw/(dfrte(nstat) - dfint(nstat))
        do 160 j = 1, n+1
        dasum(j) = dfrte(j) - dfint(j) + dratio*(dfrte(j) - dfint(j))
        wxy(1,j) = dasum(j)*dcos(dfange(j))
        wxy(2,j) = dasum(j)*dsin(dfange(j))
160     continue
        endif
c ########## Story current moments and curvatures  ########

        do 176 j = 1, n
        emom1(j) = bmrt(j) 
176     phi1(j) = phi(j)
        qp1  = q1
        dw1  = ddw

        if (q1 .lt. comstop*qpeak) then
        comst = comstop*100.
        write(6, 58) comst
58      format(/,5x, 'Lateral Concentrated Load  Less Than ', 
     +   f4.1, '% Peak Load',
     +    //, 10x, 'Computation Finish, Thank you for your effort',
     +    //, 10x, 'Good Bye!')

         stop
         endif

900     continue
        return
        end


c ******************************************************************
       subroutine respmed(p)
c ******************************************************************
c *    Subroutine resmed(p) is to compute deformation response     *
c *    for increasing end-moments  only                            *
c *                                                                *
c ******************************************************************

       implicit double precision (a-h, o-z)
       common/mats/ d, t, e, fy, tl
       common/resd1/ ires
       common/resd/  fr1, fr2
       common/dent1/ ndent(200), n, nstat
       common/dent/  detl(200), ddent(200), dbeta(200), wint(2,200)
       common/bond/ rstax, rstay, rstbx, rstby 
       common/bound/ nbond, method
       common/load1/ ip, iemax, iemay
       common/load/  eax, eay, ebx, eby, quax, quay, qubx, quby, 
     +   qcx1, qcy1, zc1, qcx2, qcy2, zc2, emax, emay, embx, emby
       common/rload/ pratio, pmin, pmax, qymin, qymax, rqxy,
     +               quymin, quymax, qrx, qry, rquxy,
     +               emxmin, emxmax, emrx, emry, redmxy
       common/capt/ py, pu, emy, emp, emu, phiy, philb
       common/mphd/ emud, empud, phipud, sd
       common/pi/ pi
       common/defm/  wxy(2,200), rotxy(2,200), wrsu(2,200),
     +               slope(2,200), phixy(2,200)
       common/dfrt/  dfint(200), dfrte(200), dfrtc(200),
     +               dfange(200), dfangc(200), dasum(200)
       common/bmom/  bmrt(200), bmag(200), dang(200), phi(200),
     +               bmxy(2,200)
       common/fact/ factor, factor1, nbuck 
       common/local/ nloca
       common/resp/ wasum(2,200), wdxy(2,200), phi1(200), emom1(200),
     +             epson(200), phimax(200)
       common/down/ ddw, dw1, comstop

c      (Assume  First Step Deflections)
        call defang(wdxy, dfange, dfrte, n)
        dratio = ddw/(dfrte(nstat) - dfint(nstat))
        do 101 j = 1, n+1
        dasum(j) = dfrte(j) - dfint(j) + dratio*(dfrte(j) - dfint(j))
        wxy(1,j) = dasum(j)*dcos(dfange(j))
        wxy(2,j) = dasum(j)*dsin(dfange(j))
 101     continue
        wdf = dfrte(nstat)

        emax1 = 0.0
        emax2 = 0.0
        np  = 0
        nbuck = 0
        do 900  m = 1, 12000
        niter   = 0
        nnter   = 0
        factor = 1.
        factor1 = 1.0
        emsta = emxmin
        emend = emxmax
        
299     if (emax1 .lt.  emax2) then 
          np = np + 1
          emend = emax1
        endif

        if (np .eq. 1) then
          empeak  = emax2 
          print*, 'Peak A-End Moment Ratio Max/Mp =',emax2*iemax
          print*, 'Peak A-End Moment Ratio May/Mp =',emax2*iemay*redmxy
          write(6,304) emax2*iemax, emax2*iemay*redmxy
304       format(5x,'Peak A-End Moment Ratio Max/Mp =',f10.3,//,
     +              'Peak A-End Moment Ratio May/Mp =',f10.3)
         endif

         emax2 = emax1
c #####  Determine  End-Moments    #######

        emstap = emsta
        emendp = emend

305     emar1 = emsta + (emend - emsta)*0.658

205     emax = emar1*iemax*emp
        embx = emax*emrx
        emay = emax*redmxy
        emby = emay*emry

        factor = 1.0
        factor1 = 1.0
        call bedm(p)
        call phimbs(phi1, emom1, phimax, p)

        fact  = 0.999999999999999
        if (factor1 .lt. fact)  then
           emar1 = emar1*factor1
           factor1 = 1.0
           nbuck = 1
          go to 205
        endif

        do 125 j=1, n+1
        phixy(2,j) = phi(j)*cos(bmag(j))
        phixy(1,j) = phi(j)*sin(bmag(j))
125     continue
        call newmark()
        call defang(wrsu, dfangc, dfrtc, n)

c #####  Check accuracy of deflections ######

        niter = niter + 1

c##### Interrupt! Iteration More than 500 Times ########
        call intrup1(nnter)
c#############################################################
        
        if (niter .gt. 50) then
        nnter = nnter + 1
        ddww = 0.5*dw1
        dasum(nstat) = dfrte(nstat) - dfint(nstat) + ddww
        dratio = ddww/(dfrte(nstat) - dfint(nstat))
        do 165 j = 1, n+1
        dasum(j) = dfrte(j) - dfint(j) + dratio*(dfrte(j) - dfint(j))
        wxy(1,j) = dasum(j)*dcos(dfange(j))
        wxy(2,j) = dasum(j)*dsin(dfange(j))
165     continue

        niter = 0
        dw1 = ddww
        emsta = emstap
        go to 305
        endif

c #### Determine the curvature ratio for every stations #######
        phira = 0.0
        do 314 j = 1, n+1
        phirat = phi1(j)/phimax(j)
        if (phirat .gt. phira) phira = phirat
314     continue

        dero = dasum(nstat) - dfrtc(nstat)
        der1 = dero/dfrtc(nstat)

        if (phira  .lt. 0.99) then
        if ( abs(der1) .gt. 0.001 ) then
          if ( dero .gt. 0.)  then
           emsta = emar1
          else
           emend = emar1
          endif
          go to 305
         endif

         else

         nbuck = 1 + nbuck

         if ( abs(der1) .gt. 0.01 ) then
          if ( dero .gt. 0.)  then
           emend = emar1
          else
           emsta = emar1
          endif
          goto 305
          endif
          endif

144     emsta = emstap
        emend = emendp

        do 145 j = 2, n
        der2 = (dasum(j) - dfrtc(j))/dfrtc(j)
        if ( abs(der2) .gt. 0.001) then
          do 136 jj = 2, n
          dasum(jj) = dfrtc(jj)
          wxy(1,jj) = dasum(jj)*dcos(dfangc(jj))
136       wxy(2,jj) = dasum(jj)*dsin(dfangc(jj))
          go to 205
         endif
145      continue

         do 155 jj = 1, n+1
         wdxy(1,jj) = wrsu(1,jj) + wint(1,jj) 
155      wdxy(2,jj) = wrsu(2,jj) + wint(2,jj)
         call defang(wdxy, dfange, dfrte, n)

         num = niter + nnter*50
       write(6, 51) num, der1, p, p*py, emax/emp, emay/emp
51     format(/, 5x, 'Iteration Number =', i6, /,
     +        5x, 'Relative  Error  =', e14.4, /,
     +        5x, 'Axial Load Ratio =', f10.4, /,
     +        5x, 'Axial Load       =', e14.4, 2x, 'N', /,
     +        5x, 'A-end Moment Ratio Max/Mp =', f10.4, /,
     +        5x, 'A-end Moment Ratio May/Mp =', f10.4)
       pc = p
       call shorten(pc, p)

       write(6, 52) 
52     format(2x,'Station',2x,'Mom-X',5x,'Def-Y',4x,'Slope-X',
     +    6x,'Mom-Y',5x,  'Def-X',4x,'Slope-Y',/,
     +    10x, '(Mx/Mp)',5x,'(mm)',4x,'(Rad)',7x,'(My/Mp)',
     +    4x, '(mm)', 6x, '(Rad)')
       write(6, 55) (j,  bmxy(1,j), wdxy(2,j), slope(2,j), bmxy(2,j),
     +               wdxy(1,j), slope(1,j),  j=1, n+1)

55    format(/, i6, 2f10.3,  e12.3, 2f10.3, e12.3)
c ############################################################
         call intrup2(dfrte(nstat), wdf)
         wdf = dfrte(nstat)
c  ####### Assume next deflections #######

        dasum(nstat) = dfrte(nstat) - dfint(nstat) + ddw
        dratio = ddw/(dfrte(nstat) - dfint(nstat))
        do 160 j = 1, n+1
        dasum(j) = dfrte(j) - dfint(j) + dratio*(dfrte(j) - dfint(j))
        wxy(1,j) = dasum(j)*dcos(dfange(j))
        wxy(2,j) = dasum(j)*dsin(dfange(j))
160     continue

c ########## Story current moments and curvatures  ########

        do 176 j = 1, n+1
        emom1(j) = bmrt(j) 
176     phi1(j) = phi(j)
        emax1 = emar1
        dw1  = ddw

       if (emar1  .lt. comstop*empeak) then
        comst = comstop*100.
        write(6, 58) comst
58      format(//,10x, 'End-Moments Less Than ', f4.1, '% Peak Load',
     +    //, 10x, 'Computation Finish, Thank you for your effort',
     +    //, 10x, 'Good Bye!')
        stop
        endif

900     continue

        return
        end


c ******************************************************************
       subroutine respdis(p)
c ******************************************************************
c *    Subroutine respdis(p) is to compute deformation response    *
c *    for increasing distributed loads only                       *
c *                                                                *
c ******************************************************************

       implicit double precision (a-h, o-z)
       common/mats/ d, t, e, fy, tl
       common/resd1/ ires
       common/resd/  fr1, fr2
       common/dent1/ ndent(200), n, nstat
       common/dent/  detl(200), ddent(200), dbeta(200), wint(2,200)
       common/bond/ rstax, rstay, rstbx, rstby 
       common/bound/ nbond, method
       common/load1/ ip, iemax, iemay
       common/load/  eax, eay, ebx, eby, quax, quay, qubx, quby, 
     +   qcx1, qcy1, zc1, qcx2, qcy2, zc2, emax, emay, embx, emby
       common/rload/ pratio, pmin, pmax, qymin, qymax, rqxy,
     +               quymin, quymax, qrx, qry, rquxy,
     +               emxmin, emxmax, emrx, emry, redmxy
       common/capt/ py, pu, emy, emp, emu, phiy, philb
       common/mphd/ emud, empud, phipud, sd
       common/pi/ pi
       common/defm/  wxy(2,200), rotxy(2,200), wrsu(2,200),
     +               slope(2,200), phixy(2,200)
       common/dfrt/  dfint(200), dfrte(200), dfrtc(200),
     +               dfange(200), dfangc(200), dasum(200)
       common/bmom/  bmrt(200), bmag(200), dang(200), phi(200),
     +               bmxy(2,200)
       common/fact/ factor, factor1, nbuck 
       common/local/ nloca
       common/resp/ wasum(2,200), wdxy(2,200), phi1(200), emom1(200),
     +             epson(200), phimax(200)
       common/down/ ddw, dw1, comstop

c##### Calculate Laterally Distributed Loads Response ######

c      (Assume  First Step Deflections)
        call defang(wdxy, dfange, dfrte, n)
        dratio = ddw/(dfrte(nstat) - dfint(nstat))
        do 101 j = 1, n+1
        dasum(j) = dfrte(j) - dfint(j) + dratio*(dfrte(j) - dfint(j))
        wxy(1,j) = dasum(j)*dcos(dfange(j))
        wxy(2,j) = dasum(j)*dsin(dfange(j))
101     continue
        wdf = dfrte(nstat)

        qumax1 = 0.0
        qumax2 = 0.0
        np  = 0
        nbuck = 0
        do 900  m = 1, 12000
        niter   = 0
        nnter   = 0
        factor = 1.
        factor1 = 1.
        quysta = quymin
        quyend = quymax
        
299     if (qumax1 .lt.  qumax2) then 
          np = np + 1
          quyend = qumax1
        endif

        if (np .eq. 1) then
          quypeak  = qumax2 
          print*, 'Peak A-End-y Distributed Load = ', quypeak,  'N/mm'
          print*, 'Peak A-End-x Distributed Load = ', quypeak*rquxy, 
     +    'N/mm'
          write(6,304) quypeak, quypeak*rquxy
304       format(5x,'Peak A-End-y Distributed Load = ', f15.3, 'N/mm'
     +           //,'Peak A-End-x Distributed Load = ', f15.3, 'N/mm') 

         endif

         qumax2 = qumax1
c #####  Determine  Distributed Loads    #######

        quystap  = quysta 
        quyendp  = quyend

305     quay1 = quysta + (quyend - quysta)*0.658

205     quay = quay1
        quby = quay*qry
        quax = quay*rquxy
        qubx = quax*qrx

        factor = 1.0
        factor1 = 1.0
        call bedm(p)
        call phimbs(phi1, emom1, phimax, p)

        fact  = 0.999999999999999
        if (factor1 .lt. fact)  then
           quay1 = quay1*factor1
           factor1 = 1.0
           nbuck = 1
          go to 205
        endif

        do 125 j=1, n+1
        phixy(2,j) = phi(j)*cos(bmag(j))
        phixy(1,j) = phi(j)*sin(bmag(j))
125     continue
        call newmark()
        call defang(wrsu, dfangc, dfrtc, n)

c #####  Check accuracy of deflections ######

        niter = niter + 1

c##### Interrupt! Iteration More than 500 Times ########
        call intrup1(nnter)
c#############################################################
        
        if (niter .gt. 50) then
        nnter = nnter + 1
        ddww = 0.5*dw1
        dasum(nstat) = dfrte(nstat) - dfint(nstat) + ddww
        dratio = ddww/(dfrte(nstat) - dfint(nstat))
        do 165 j = 1, n+1
        dasum(j) = dfrte(j) - dfint(j) + dratio*(dfrte(j) - dfint(j))
        wxy(1,j) = dasum(j)*dcos(dfange(j))
        wxy(2,j) = dasum(j)*dsin(dfange(j))
165     continue

        niter = 0
        dw1 = ddww
        quysta = quystap
        go to 305
        endif

c #### Determine the curvature ratio for every stations #######
        phira = 0.0
        do 314 j = 1, n+1
        phirat = phi1(j)/phimax(j)
        if (phirat .gt. phira) phira = phirat
314     continue

        dero = dasum(nstat) - dfrtc(nstat)
        der1 = dero/dfrtc(nstat)

        if (phira  .lt. 0.99) then
        if ( abs(der1) .gt. 0.001 ) then
          if ( dero .gt. 0.)  then
           quysta = quay1
          else
           quyend = quay1
          endif
          go to 305
         endif
   
         else
         nbuck = 1 + nbuck

         if ( abs(der1) .gt. 0.01 ) then
          if ( dero .gt. 0.)  then
           quyend = quay1
          else
           quysta = quay1
          endif
          goto 305
          endif
          endif

144     quysta = quystap
        quyend = quyendp

        do 145 j = 2, n
        der2 = (dasum(j) - dfrtc(j))/dfrtc(j)
        if ( abs(der2) .gt. 0.001) then
          do 136 jj = 2, n
          dasum(jj) = dfrtc(jj)
          wxy(1,jj) = dasum(jj)*dcos(dfangc(jj))
136       wxy(2,jj) = dasum(jj)*dsin(dfangc(jj))

          go to 205
         endif
145      continue

         do 155 jj = 1, n+1
         wdxy(1,jj) = wrsu(1,jj) + wint(1,jj) 
155      wdxy(2,jj) = wrsu(2,jj) + wint(2,jj)
         call defang(wdxy, dfange, dfrte, n)
       
         num = niter + nnter*50
       write(6, 51) num, der1, p, p*py, quay, quax
51     format(/,5x, 'Iteration Number =', i6, /,
     +        5x, 'Relative  Error  =', e14.4, /,
     +        5x, 'Axial Load Ratio =', f10.4, /,
     +        5x, 'Axial Load       =', e14.4, 2x, 'N',  /,
     +        5x, 'A-end Distributed Load (Y-Y) =', e14.4, 'N/mm', /,
     +        5x, 'A-end Distributed Load (X-X) =', e14.4, 'N/mm')
       pc = p
       call shorten(pc, p)

       write(6, 52) 
52     format(2x,'Station',2x,'Mom-X',5x,'Def-Y',4x,'Slope-X',
     +    6x,'Mom-Y',5x,  'Def-X',4x,'Slope-Y',/,
     +    10x, '(Mx/Mp)',5x,'(mm)',4x,'(Rad)',7x,'(My/Mp)',
     +    4x, '(mm)', 6x, '(Rad)')
       write(6, 55) (j,  bmxy(1,j), wdxy(2,j), slope(2,j), bmxy(2,j),
     +               wdxy(1,j), slope(1,j),  j=1, n+1)

55    format(/, i6, 2f10.3,  e12.3, 2f10.3, e12.3)
c ############################################################
         call intrup2(dfrte(nstat), wdf)
         wdf = dfrte(nstat)

c  ####### Assume next deflections #######

        dasum(nstat) = dfrte(nstat) - dfint(nstat) + ddw
        dratio = ddw/(dfrte(nstat) - dfint(nstat))
        do 160 j = 1, n+1
        dasum(j) = dfrte(j) - dfint(j) + dratio*(dfrte(j) - dfint(j))
        wxy(1,j) = dasum(j)*dcos(dfange(j))
        wxy(2,j) = dasum(j)*dsin(dfange(j))
 160     continue

c ########## Story current moments and curvatures  ########

        do 176 j = 1, n+1
        emom1(j) = bmrt(j) 
176     phi1(j) = phi(j)
        qumax1  = quay1
        dw1  = ddw

       if (quay1  .lt. comstop*quypeak) then
        comst = comstop*100.
        write(6, 58) comst
58      format(/,5x, 'Linearly Distributed Load Less Than ', 
     +    f4.1, '% Peak Load',
     +    //, 10x, 'Computation Finish, Thank you for your effort',
     +    //, 10x, 'Good Bye!')
        stop
        endif

900     continue
        return
        end


c ******************************************************************
      subroutine bedm(p)
c ******************************************************************
c *                                                                *
c *   Subroutine bedm(p) is to compute bending moments  at every   *
c *   stations with respect to X-X and Y-Y axes,  respectively,    *
c *   and magnitude and direction of resultant  moments.           *
c *                                                                *
c * Variables:                                                     *
c *    p   = axial load normalized by Py                           *
c *    ea  = eccentricity of axial load at A-end                   *
c *    eb  = eccentricity of axial load at B-end                   *
c *    qu  = uniform load                                          *
c *    qc  = concentrated load                                     *
c *    zc  = distance from A-end to concentrated load              *
c *   bmxy(2, n+1) = bending moments array with respect to         *
c *                  X-X and Y-Y axes                              *
c *   bmag(n+1) = directional angle array with respect to          *
c *               X-X axis for resultant moments                   *
c *   bmrt(n+1) = magnitude array of resultant moments             *
c *               to applied bending moments                       *
c *                                                                *
c ******************************************************************

      implicit double precision (a-h, o-z)
      common/mats/  d, t, e, fy, tl
      common/load1/ ip, iemax, iemay
      common/load/  eax, eay, ebx, eby, quax, quay, qubx, quby, 
     +   qcx1, qcy1, zc1, qcx2, qcy2, zc2, emax, emay, embx, emby
      common/dent1/ ndent(200), n, nstat
      common/dent/  detl(200), ddent(200), dbeta(200), wint(2,200)
      common/capt/ py, pu, emy, emp, emu, phiy, philb
      common/bond/ rstax, rstay, rstbx, rstby 
      common/bound/ nbond, method
      common/bmom/  bmrt(200), bmag(200), dang(200), phi(200),
     +               bmxy(2,200)
      common/defm/  wxy(2,200), rotxy(2,200), wrsu(2,200),
     +              slope(2,200), phixy(2,200)
      common/pi/    pi

c ##### Calculate reaction at A-end #####
       do 605 j = 1, n 
       rotxy(1, j) = slope(1,j)
       rotxy(2, j) = slope(2,j)
605    continue
       pn = p*py

c ##### Simply Supported Members ############
       if (nbond .eq. 100) then
      
       vax = (pn*(ebx - eax) - 
     +       (rstay*rotxy(1,1) + rstby*rotxy(1,n)) +
     +       (emay - emby))/tl -
     +       quax*tl/2. - (qubx - quax)*tl/6. -
     +       qcx1*(tl - zc1)/tl - qcx2*(tl -zc2)/tl
       vay = (pn*(eby - eay) - 
     +       (rstax*rotxy(2,1) + rstbx*rotxy(2,n))  +
     +       (embx - emax)) /tl -
     +       quay*tl/2. - (quby - quay)*tl/6. -
     +       qcy1*(tl - zc1)/tl - qcy2*(tl -zc2)/tl
c ##### Calculate A-end-moments ######
       bmxy(1, 1) = -pn*eay - rstax*rotxy(2,1) - emax
       bmxy(2, 1) =  pn*eax + rstay*rotxy(1,1) - emay
       z = 0.
       do 610 j = 1, n
       z = z + detl(j)

c #####  Calculate moments at every stations #####
       dz1 = z - zc1 
       dz2 = z - zc2
       if (dz1 .lt. 0.0)  dz1 = 0.0
       if (dz2 .lt. 0.0)  dz2 = 0.0
       bmxy(1, j+1) = - pn*(eay - wint(2, j+1) - wxy(2, j+1) ) -
     +                emax - rstax*rotxy(2,1) - vay*z - quay*z*z/2. - 
     +               (quby - quay)*z*z*z/(6.*tl) - qcy1*dz1 - qcy2*dz2
       bmxy(2, j+1) =  pn*(eax - wint(1, j+1) - wxy(1, j+1) ) -
     +                emay - rstay*rotxy(1,1) + vax*z + quax*z*z/2. + 
     +               (qubx - quax)*z*z*z/(6.*tl) + qcx1*dz1 + qcx2*dz2
610    continue
       endif

c ##### Cantilever Members ##########
       if (nbond .eq. 101) then
      
c ##### Calculate A-end-moments ######
       bmxy(1, 1) = -pn*eay - emax
       bmxy(2, 1) =  pn*eax - emay
       z = 0.
       do 100 j = 1, n
       z = z + detl(j)

c #####  Calculate moments at every stations #####
       dz1 = z - zc1 
       dz2 = z - zc2
       if (dz1 .lt. 0.0)  dz1 = 0.0
       if (dz2 .lt. 0.0)  dz2 = 0.0
       bmxy(1, j+1) = - pn*(eay + wint(2,1) + wxy(2,1) - wint(2, j+1) 
     +               - wxy(2, j+1) ) -  emax - quay*z*z/2. - 
     +               (quby - quay)*z*z*z/(6.*tl) - qcy1*dz1 - qcy2*dz2
       bmxy(2, j+1) =  pn*(eax + wint(1,1) + wxy(1,1) - wint(1, j+1) 
     +                - wxy(1, j+1) ) - emay + quax*z*z/2. + 
     +               (qubx - quax)*z*z*z/(6.*tl) + qcx1*dz1 + qcx2*dz2
100    continue
       endif

c ##### Calculate resultant moment magnitude and direction angle #####
       do 620 j = 1, n+1 
       bmrt(j) = sqrt( bmxy(1,j)*bmxy(1,j) + bmxy(2,j)*bmxy(2,j) )
        if (bmxy(1,j) .eq. 0.0 .and. bmxy(2,j) .eq. 0.0) then
           bmag(j) = 0.0
        elseif (bmxy(1,j) .le. 0.0) then
           bmag(j) = pi - dasin( bmxy(2,j)/bmrt(j) )
        elseif (bmxy(2,j) .gt. 0.0) then
           bmag(j) = dasin( bmxy(2,j)/bmrt(j) )
        else
           bmag(j) = 2.*pi + dasin( bmxy(2,j)/bmrt(j) )
        endif
620     continue
        do 630 j =1, n+1
        bmrt(j) = bmrt(j)/emy
        bmxy(1,j) = bmxy(1,j)/emp
        bmxy(2,j) = bmxy(2,j)/emp
630     continue
       return 
       end


c ******************************************************************
      subroutine phimbr(phi1, emom1, phimax, p)
c ******************************************************************
c *                                                                *
c *    Subroutine phimbr(phi1, emom1, phimax, p) is to compute     *
c *    curvatures at all stations along the member for initial     *
c *    constant axial load.                                        *
c *                                                                *
c * Variables:                                                     *
c *   phi1   = normalized curvature of segment  at last load step  *
c *   emom1  = normalized bending moment at last load step         *
c *   phimax = maximum  curvature of segment                       *
c *   p    = axial load normalized by Py                           *
c *                                                                *
c ******************************************************************

       implicit double precision (a-h, o-z)
       common/mats/ d, t, e, fy, tl
       common/resd1/ ires
       common/resd/  fr1, fr2
       common/dent1/ ndent(200), n, nstat
       common/dent/  detl(200), ddent(200), dbeta(200), wint(2,200)
       common/capt/ py, pu, emy, emp, emu, phiy, philb
       common/mphd/ emud, empud, phipud, sd
       common/pi/ pi
       common/defm/  wxy(2,200), rotxy(2,200), wrsu(2,200),
     +               slope(2,200), phixy(2,200)
       common/bmom/  bmrt(200), bmag(200), dang(200), phi(200),
     +               bmxy(2,200)
       common/fact/ factor, factor1, nbuck 
       common/local/ nloca
       dimension   phi1(200), emom1(200), phimax(200)


        do 110 kk = 1, n
        if (ndent(kk) .eq. 1) then
         dang(kk) = theta(bmag(kk), dbeta(kk))
         dang(kk+1) = theta(bmag(kk+1), dbeta(kk))
         avdang = (dang(kk) + dang(kk+1))/2.
         avphi1 = (phi1(kk) + phi1(kk+1))/2.
         avemom1 = (emom1(kk) + emom1(kk+1))/2.
         avbmrt  = (bmrt(kk) + bmrt(kk+1))/2.
         call mphidt(avphi1, avemom1, avdang, ddent(kk), 
     +              phi(kk), avbmrt, p, phimax(kk))
         phimax(kk+1) = phimax(kk)
         phi(kk+1) = phi(kK)
        elseif (kk .eq. 1) then
         call mphiud(phi1(1), emom1(1), phi(1), bmrt(1), p, phimax(1))
         call mphiud(phi1(2), emom1(2), phi(2), bmrt(2), p, phimax(2))
        elseif (ndent(kk+1) .ne.  1) then
         call mphiud(phi1(kk+1), emom1(kk+1), phi(kk+1), bmrt(kk+1), 
     +               p, phimax(kk+1))
        endif
110     continue
         return
         end


c ******************************************************************
      subroutine phimbs(phi1, emom1, phimax, p)
c ******************************************************************
c *                                                                *
c *   Subroutine phimbs(phi1, emom1, phimax, p) is to compute      *
c *   curvatures at all stations along the member for constant     *
c *   axial load and increasing lateral loads                      *
c *                                                                *
c * Variables:                                                     *
c *   phi1   = normalized curvature of segment  at last load step  *
c *   emom1  = normalized bending moment at last load step         *
c *   phimax = maximum  curvature of segment                       *
c *   p    = axial load normalized by Py                           *
c *                                                                *
c ******************************************************************

       implicit double precision (a-h, o-z)
       common/mats/ d, t, e, fy, tl
       common/resd1/ ires
       common/resd/  fr1, fr2
       common/dent1/ ndent(200), n, nstat
       common/dent/  detl(200), ddent(200), dbeta(200), wint(2,200)
       common/capt/ py, pu, emy, emp, emu, phiy, philb
       common/mphd/ emud, empud, phipud, sd
       common/pi/ pi
       common/defm/  wxy(2,200), rotxy(2,200), wrsu(2,200),
     +               slope(2,200), phixy(2,200)
       common/bmom/  bmrt(200), bmag(200), dang(200), phi(200),
     +               bmxy(2,200)
       common/fact/ factor, factor1, nbuck 
       common/local/ nloca
       dimension   phi1(200), emom1(200), phimax(200)

        do 105 kk = 1, n
        if (ndent(kk) .eq. 1) then
         dang(kk) = theta(bmag(kk), dbeta(kk))
         dang(kk+1) = theta(bmag(kk+1), dbeta(kk))
         avdang = (dang(kk) + dang(kk+1))/2.
         avphi1 = (phi1(kk) + phi1(kk+1))/2.
         avemom1 = (emom1(kk) + emom1(kk+1))/2.
         avbmrt  = (bmrt(kk) + bmrt(kk+1))/2.
         call mphidt(avphi1, avemom1, avdang, ddent(kk), 
     +              phi(kk), avbmrt, p, phimax(kk))
         phi(kk+1) = phi(kK)
         phimax(kk+1) = phimax(kk)
            if (factor .lt. factor1) then
                factor1 = factor
                factor = 1.0
             endif

        elseif (kk .eq. 1) then
         call mphiud(phi1(1), emom1(1), phi(1), bmrt(1), p, phimax(1))
         call mphiud(phi1(2), emom1(2), phi(2), bmrt(2), p, phimax(2))
            if (factor .lt. factor1) then
                factor1 = factor
                factor = 1.0
             endif

        elseif (ndent(kk+1) .ne.  1) then
         call mphiud(phi1(kk+1), emom1(kk+1), phi(kk+1), bmrt(kk+1), 
     +               p, phimax(kk+1))
            if (factor .lt. factor1) then
                factor1 = factor
                factor = 1.0
             endif
        endif
105     continue

        return
        end


c ******************************************************************
      subroutine mphiud(phic, emom, phit, emt, p, phimax)
c ******************************************************************
c *                                                                *
c *   Subroutine mphiud(phic, emom, phit, emt, p, phimax)          *
c *   is to compute curvature for a given moment and axial         *
c *   load for undented tubular sections                           *
c *                                                                *
c * Variables:                                                     *
c *   phic = normalized curvature of segment  at last load step    *
c *   emom = normalized bending moment at last load step           *
c *   phit = computed  curvature of segment                        *
c *   emt  = computed bending moment normalized by My              *
c *   p    = axial load normalized by Py                           *
c *   phimax = maximum curvature at last load step                 *
c *                                                                *
c ******************************************************************

      implicit double precision (a-h, o-z)
      common/mats/ d, t, e, fy, tl
      common/mtph/ a, b, c, f, em1, em2, empc, phi1, phi2
      common/mphd/ emud, empud, phipud, sd
      common/dscn/ emmin, emmax, eimax
      common/resd1/ ires
      common/resd/  fr1, fr2
      common/pi/ pi 
      common/capt/ py, pu, emy, emp, emu, phiy, philb
      common/fact/ factor, factor1, nbuck 
      common/local/ nloca

       call resid(p)

c ##### Determine local buckling starting curvature and moment #####
        call mpud(p)
        call abcf(p)
c########  Local Buckling Behavior for Undented Sections ########

        if (nloca .eq. 1) then

        philb = phibck(p)
        phimax = philb
        if (philb .le. phi1) then
           emmax = philb*a
        elseif (philb .le. phi2) then
           emmax = b - c/sqrt(philb)
        else
           emmax = empc - f/(philb*philb)
        endif

c ######
       if (phic .lt. philb .and.
     +         abs((emt - emmax)/emmax) .le. 0.0001)  then
          emt = emmax
          goto 661
        elseif (emt .gt. emmax) then
            factor = emmax/emt
            goto 650
        endif

c ##### Determine curvature for a undented section #####
 661       if (phic .lt. 0.99*philb ) then
c**** phit is lastest curvature obtained form last calculation

         if ( emt .le. emmax) then
           if (emt .lt. em1) then
             phit = emt/a
           elseif (emt .lt. em2) then
             phit = (c/(b - emt))**2
           else
             phit = sqrt(f/(empc - emt))
           endif
           if (phit .lt. phic) then
             if (phit .gt. phi1) then
             phit = phic - (emom - emt)
             endif
           endif
         endif
          else

660           call  descen(p)
c#########
            nbuck = 1
c###########

             phit = log((emt - emmin)/(emmax - emmin))*
     +              (emmax - emmin)/eimax + philb
        endif

        endif
c ############# Local Buckling not Considered for Undented Sections ###
        if (nloca .eq. 0) then
           phimax = 1000.
            if ( emt .gt. empc) then
            factor = empc/emt
            goto 650
            endif
           if (emt .lt. em1) then
             phit = emt/a
           elseif (emt .lt. em2) then
             phit = (c/(b - emt))**2
           else
             phit = sqrt(f/(empc - emt))
           endif
           if (phit .lt. phic) then
             if (phit .gt. phi1) then
             phit = phic - (emom - emt)
             endif
           endif
         endif

       return
650   end
       

c ******************************************************************
      subroutine mphidt(phic, emom, beta, dd,  phit, emt, p, phimax)
c ******************************************************************
c *                                                                *
c *   Subroutine mphidt(phic, emom, beta,dd,phit,emt,p,phimax)     *
c *   is to compute curvature for a given moment and axial         *
c *   load for dented tubular sections                             *
c *                                                                *
c * Variables:                                                     *
c *   phic = normalized curvature of segment  at last load step    *
c *   emom = normalized bending moment at last load step           *
c *   beta = dent directional angle with respect to negative       *
c *          bending moment                                        *
c *   dd   = debt depth                                            *
c *   phit = computed  curvature of  a segment                     *
c *   emt  = computed bending moment normalized by My              *
c *   p    = axial load normalized by Py                           *
c *   phimax = maximum curvature at last load step                 *
c *   Mud  = moment capacity of dented section                     *
c *          normalized by Mp                                      *
c *   Pud  = axial yield strength of dented section                *
c *   Sd   = slope function of descending branch                   *
c *                                                                *
c ******************************************************************

      implicit double precision (a-h, o-z)
      common/mats/ d, t, e, fy, tl
      common/mtph/ a, b, c, f, em1, em2, empc, phi1, phi2
      common/mphd/ emud, empud, phipud, sd
      common/dscn/ emmin, emmax, eimax
      common/resd1/ ires
      common/resd/  fr1, fr2
      common/pi/ pi 
      common/capt/ py, pu, emy, emp, emu, phiy, philb
      common/fact/ factor, factor1, nbuck 

       call resid(p)
c ##### Determine curvature for a dented section #####

        call mpdt (beta, dd, p)
        call abcf(p)
        phimax = phipud
c ######
       if (abs((emt - empud)/empud) .le. 0.0001
     +         .and.  phic .lt. phipud)  then
          emt = empud
          goto 653 
        elseif (emt .gt. empud) then
            factor = empud/emt
            goto 651
        endif

 653      if (phic .lt. 0.99*phipud ) then
          if (emt .le. empud) then
           if (emt .lt. em1 ) then
            phit = emt/a
           else
            phit = (c/(b - emt))**2
           endif
          endif

           if (phit .lt. phic) then
             if (phit .gt. phi1) then
             phit = phic - (emom - emt)/a
             endif
          endif
 
         else
652        nbuck = 1
         phit = ((1. - emt/empud)/sd + 1.)* phipud

         endif
       return
651     end


c ******************************************************************
      function phibck(p)
c ******************************************************************
c *                                                                *
c *   Function phibck(p) is to calculate the critical  curvature   *
c *   at which local buckling  starts  for a given value of axial  *
c *   for an undented tubular section                              *
c *                                                                *
c * Variables:                                                     *
c *    p   = axial load normalized by Py                           *
c ******************************************************************

       implicit double precision (a-h, o-z)
       common/mats/ d, t, e, fy, tl

       dot = d/t*0.01 
       if (p .lt. 0.4) then
        if (dot .lt. 0.72) then
            phibck = 1./(-0.292 + 1.06*dot + 0.336*dot*dot) +
     +              p/(0.068 + 0.061*dot - 1.759*dot*dot)
         else
             phibck = 2.0 - 1.25*p - 0.625*dot
         endif
        endif
        if (p .ge. 0.4) then
         if (dot .lt. 0.72) then
             phibck = 1./(-0.644 + 2.567*dot - 0.486*dot*dot) +
     +               (p - 0.4)/(2.663 - 12.03*dot - 7.71*dot*dot)
         else
             phibck = 1.7 - 0.5*p - 0.625*dot
         endif
       endif
       end


c ******************************************************************
      function theta(aglm, abeta)
c ******************************************************************
c *   Function  theta(aglm, abeta) is to compute dent directional  *
c *   angle that is between negative bending moment axis (dent at  *
c *   compression) and  bending moment axis                        *
c *                                                                *
c * Variables:                                                     *
c *   aglm =  directional angle of resultant moment with           *
c *           respect to  X-X  axis                                *
c *   abeta = directional angle of dent with respect to            *
c *           X-X axis                                             *
c *   theta = dent directional angle between negative bending      *
c *           moment axis and applied bending moment axis          *
c *                                                                *
c ******************************************************************
 
       implicit double precision (a-h, o-z)
       common /pi/ pi

       if (abs(aglm - abeta) .le. pi) then
          theta = abs(aglm - abeta)
        else
          theta = 2.*pi - abs(aglm - abeta)
        endif
        end



c ******************************************************************
      subroutine abcf()
c ******************************************************************
c *                                                                *
c *   Subroutine abcf() is  to determine the constants a, b, c     *
c *   and f for a given three-regime M-P-PHI  curve                *
c *                                                                *
c ******************************************************************

      implicit double precision (a-h, o-z)
      common/mtph/ a, b, c, f, em1, em2, empc, phi1, phi2

      a  = em1/phi1
      b  = (em2*sqrt(phi2) - em1*sqrt(phi1))/
     +     (sqrt(phi2) - sqrt(phi1))
      c  = (em2 - em1)/(1./sqrt(phi1) - 1./sqrt(phi2))
      f  = (empc - em2)*phi2*phi2

      return
      end



c ******************************************************************
      subroutine mpud(p)
c ******************************************************************
c *                                                                *
c *   Subroutine mpud(p) is to compute boundaries of the three     *
c *   regime M-P-PHI curve for a given value of axial load on      *
c *   an undented tubular section                                  *
c *                                                                *
c * Variables:                                                     *
c *    p   = axial load normalized by Py                           *
c *                                                                *
c ******************************************************************
 
       implicit double precision (a-h, o-z)
       common/mtph/ a, b, c, f, em1, em2, empc, phi1, phi2
       common/resd1/ ires
       common/resd/  fr1, fr2

c ##### Calculate em1, em2, empc, phi1 and  phi2 #####
       em1 = fr1*(1. - p)
       em2 = fr1*(1.  - p*p)
       empc = 1.273*(1. - P**1.75)
       phi1 = em1
       phi2 = fr2*(1. + p*p)

       return
       end


c ******************************************************************
      subroutine descen(p)
c ******************************************************************
c *                                                                *
c *   Subroutine descen(p) is to calculate the parameters  of      *
c *   the descending branch of M-P-PHI curves for locally buckle   *
c *   sections                                                     *
c *                                                                *
c * Variable:                                                      *
c *    p   = axial load normalized by Py                           *
c *                                                                *
c ******************************************************************

       implicit double precision (a-h, o-z)
       common/mats/ d, t, e, fy, tl
       common/dscn/ emmin, emmax, eimax

       dot = d/t*0.01 
       if (p .lt. 0.4) then
        if (dot .lt. 0.72) then
            emmin = 1./(1./(0.75 - 0.514*dot) + 
     +              (15.86 + 12.89*dot)*p +
     +              (104. - 710.8*dot + 1036.*dot*dot)*p*p)
            eimax = -0.094 - 0.129*p + 0.367*dot + 0.77*p*dot
         else
            emmin = 1./(1./(0.53 - 0.208*dot) + 
     +              25.14*p + 129.04*p*p)
            eimax = 0.17 + 0.43*p
         endif
       endif
       if (p .ge. 0.4) then
        if (dot .lt. 0.72) then
            emmin = (0.617 - 1.343*dot + 0.772*dot*dot)*(1. - p)
            eimax = -0.146 + 0.675*p
         else
            emmin = 0.05*(1. - p)
            eimax = 0.34
         endif
       endif
        eimax = -eimax
       return
       end


c ******************************************************************
      subroutine mpdt(beta ,dd, p)
c ******************************************************************
c *                                                                *
c *   Subroutine mpdt(beta, dd, p)  is  to  compute  boundary      *
c *   parameters of the three-regime of M-P-PHI curves for  a      *
c *   given value  of axial load on a dented tubular section       *
c *                                                                *
c * Variables:                                                     *
c *   beta = dent directional angle with respect to negative       *
c *          moment direction (degree)                             *
c *    dd  = debt depth                                            *
c *    p   = axial load normalized by Py                           *
c *    Mud = moment capacity of dented section                     *
c *          normalized by Mp                                      *
c *    Pud = axial yield strength of dented section                *
c *    Sd  = slope function of descending branch                   *
c *                                                                *
c ******************************************************************
     
      implicit double precision (a-h, o-z)
      common/mats/ d, t, e, fy, tl
      common/mtph/ a, b, c, f, em1, em2, empc, phi1, phi2
      common/mphd/ emud, empud, phipud, sd
      common/resd1/ ires
      common/resd/  fr1, fr2
      common/pi/ pi
      common/capt/ py, pu, emy, emp, emu, phiy, philb

c ##### Determine limit of dent angle Beta #####
      betat  = beta
      bet = betat
      if (bet  .gt. pi/2.)  bet = pi/2.
c ##### Calculate  m1, mpud, phi1 and phipud  #####

      emud  = exp(-0.06*dd/t*cos(bet))
      pud   = exp(-0.08*dd/t)
      alpht = 1.75 - 0.1*dd/t*(1. - 2*betat/pi)
      if (alpht .le. 1.0) alpht = 1.0
      empud = 1. - (p*py/(pud*pu))**alpht
      
      empud = empud*emud*emu/emy
      em1  = 0.8*fr1*empud
      phi1 = fr1*(1. - p)*(1. - dd/d*sin(bet))
      phi0 = 2.8 - 0.1*dd/t - 2.5*p
      if (phi0 .le. 1.0) phi0 = 1.0
      phipud = (1. + 2.*betat/pi)*phi0
      em2   =  empud

      phi2   =  phipud
      empc  =  empud
c ##### Calculate slope function of descending branch #####
      sd = 0.1 + 0.4*p + 0.6*sin(bet) + 0.8*p*sin(bet)
      return
      end


c ******************************************************************
      subroutine resid (p)
c ******************************************************************
c *                                                                *
c *   Subroutine resid(p) is  to determine the residual stresses   *
c *   factors  f1(R) and f2(R) taking into account the effects    *
c *   of residual stresses on the M-P-PHI curve                    *
c *                                                                *
c *  Variables:                                                    *
c *   ires = indicator for considering residual stresses           *
c *        = 1 = m-p-phi curve with residual stresses              *
c *        = 0 = m-p-phi curve without residual stresses           *
c *    p   = axial load normalized by Py                           *
c *                                                                *
c ******************************************************************

       implicit double precision (a-h, o-z)
       common/resd1/ ires
       common/resd/  fr1, fr2

      if (ires .eq. 1) then
        fr1 = 0.9
        fr2 = 0.9 + 0.2*p
       elseif (ires .eq. 0) then
        fr1 = 1.0
        fr2 = 1.0
       else
        write(6, 560) ires
560     format(//, 8x, 'Residual Stress Indicator  ires =', i4,
     +          /, 10x,'Please Check Your Input of Indicator for',
     +          /, 10x,  ' Residual Stresses',
     +          /, 10x, 'NOTE THAT:',
     +          /, 10x,'     ires = 1 --- with residual stress',
     +          /, 10x,'    ires = 0 --- without residual stress')
       stop
       endif 

       return
       end


c ******************************************************************
         subroutine shorten(pc, p)
c ******************************************************************
c *                                                                *
c *     Subroutine shorten(pc, p) is to computer the shortening    *
c *     of a member due to axial load and lateral displacements    *
c *                                                                *
c * Variables:                                                     *
c *   pc     =  normalized axial load  at last load step           *
c *   p      =  current axial load normalized by Py                *
c *                                                                *
c ******************************************************************
 
       implicit double precision (a-h, o-z)
       common/mats/ d, t, e, fy, tl
       common/dent1/ ndent(200), n, nstat
       common/dent/  detl(200), ddent(200), dbeta(200), wint(2,200)
       common/capt/ py, pu, emy, emp, emu, phiy, philb
       common/defm/  wxy(2,200), rotxy(2,200), wrsu(2,200),
     +               slope(2,200), phixy(2,200)
       common/dfrt/  dfint(200), dfrte(200), dfrtc(200),
     +               dfange(200), dfangc(200), dasum(200)
       common/bmom/  bmrt(200), bmag(200), dang(200), phi(200),
     +               bmxy(2,200)
       common/resp/ wasum(2,200), wdxy(2,200), phi1(200), emom1(200),
     +             epson(200), phimax(200)

c ######   Computer the Relative Deflection of Dent Segment #####
         shortd = 0.0
         do 177  j = 1, n
         if  (ndent(j) .eq. 1) then
         dwdtx  = -(phixy(1, j)*phiy*detl(j)*detl(j)/8.)
         dwdty  = phixy(2, j)*phiy*detl(j)*detl(j)/8.
         dwdgx    = dwdtx + (wdxy(1, j) + wdxy(1, j+1))/2.
         dwdgy    = dwdty + (wdxy(2, j) + wdxy(2, j+1))/2.
         dwdgxy   = sqrt(dwdtx*dwdtx + dwdty*dwdty)
c ####### Computer the Relative Shortening of Dent Segment ######

         shortd  = 2.* (detl(j)/2. - sqrt(detl(j)*detl(j)/4. -
     +             dwdgxy*dwdgxy)) + shortd    
         write(6, 50) j, dwdgy, dwdgx, shortd
50       format(5x, 'Dent Segment          =', i6, /,
     +          7x, 'Total Deflection -Y   =', f10.3, 3x, 'mm',/,
     +          7x, 'Total Deflection -X   =', f10.3, 3x, 'mm',/,
     +          7x, 'Local Shortening      =', f10.3, 3x, 'mm',)

         endif
177      continue

c##### Compute axial shortening of the member ######
        deltas = 0.0
        deltag = 0.0
        do 175  j = 1, n
        emtt = bmrt(j+1)
        epslon1 = epson(j+1)
        call epsilon (emtt, epslon1, pc, epslons, p)
        deltas = deltas + detl(j)*epslons
        deltag = deltag + (detl(j) - sqrt(detl(j)*detl(j) -  
     +         (dfrte(j) - dfrte(j+1))*(dfrte(j) - dfrte(j+1))))

        epson(j+1) = epslons
175      continue
        dshort = deltas*fy/e + deltag + shortd 
        write(6,51) dshort, dshort/tl
51      format(5x, 'Axial Shortening of Member  =', f10.3, 3x, 'mm',/,
     +         5x, 'Axial Shortening/L          =', e15.4,/)
       
       return
       end

c ******************************************************************
      subroutine epsilon (emt, epslon1, pc, epslon, p)
c ******************************************************************
c *                                                                *
c *   Subroutine epsilon (emt, epslon1, pc, epslon, p) is to       *
c *   compute axial strain for a given moment and axial load       *
c *   on tubular sections                                          *
c *                                                                *
c * Variables:                                                     *
c *   emt     = bending moment normalized by My                    *
c *   epslon1 = normalized axial strain at last load step          *
c *   pc     =  normalized axial load  at last load step           *
c *   epslon =  current axial strain normalized by yield strain    *
c *   p      =  current axial load normalized by Py                *
c *                                                                *
c ******************************************************************

      implicit double precision (a-h, o-z)
      common/mats/ d, t, e, fy, tl
      common/capt/ py, pu, emy, emp, emu, phiy, philb
      common/dent1/ ndent(200), n, nstat


c ####   Compute boundaries of the three regimes  of 
c        M-P-EPSILON curve for given value  of moment 
c        for circular tubular sections 

c ##### Calculate eps1, eps2, pm1, pm2 and  pmax #####

       emt = emt*emy/emp
       if (emt .le. 0.0) emt = 0.01
       pmax = (1. - emt)**0.57

       if (emt .lt. 0.75) then
        pm1 = (1. - emt)**1.2
        pm2 = (1. - 0.9*emt)**0.8
        eps1 = (1. - emt)**1.2
        eps2 = 1. + emt*emt
       else
        pm1 = (1. - emt)**0.9
        pm2 = 1.3 - 1.18*emt
        eps1 = 1.2 - emt
        eps2 = 1.0
       endif


c #####  Compute the constants  b, c, f and ek1 for  
c        given three-regimes of M-P-EPSILON  curve

      b  = (pm2*sqrt(eps2) - pm1*sqrt(eps1))/
     +     (sqrt(eps2) - sqrt(eps1))
      c  = (pm2 - pm1)/(1./sqrt(eps1) - 1./sqrt(eps2))
      f  = (pmax - pm2)*eps2*eps2

      ek1 = (eps1 - pm1)/pm1/pm1

c ############## Dented Member Effects #####################
      do 100 j=1, n
      if (ndent(j) .eq. 1)  mn = 1
100   continue
c########

      if (p .le. pm1) then
         if (emt .lt. 0.75) then
              epslon = p
         else
              epslon = p + ek1*p*p
         endif
       elseif (p .le. pm2) then
             epslon = (c/(b - p))*(c/(b - p))
       else
             epslon = sqrt(f/(pmax - p)) 
       endif

c######  Check Unloading #########
       if (epslon .lt. epslon1) then
         if (epslon .gt. eps1) then
           epslon = epslon1 - (pc - p)
          endif
        endif
      if (epslon .lt. epslon1 .and. mn .eq. 1) epslon = epslon1
       return
       end


c ******************************************************************
      subroutine newmark()
c ******************************************************************
c *                                                                *
c *   Subroutine newmark() is to compute the deflections           *
c *   at all  stations along the  member by  Newmark's             *
c *   integration  procedure.                                      *
c *                                                                *
c * Variables:                                                     *
c *   wint(Ix, j) = initial deflection array                       *
c *   wasm(Ix, j) = assumed deflection array                       *
c *   wrsu(Ix, j) = resultant deflection array                     *
c *   Ix          = 1- X- direction; =2-- Y-direction              *
c *   detl(j)     = length array of segment                        *
c *   alph(Ix, j) = equivalent concentrated factor array of        *
c *                 curvature distribution                         *
c *   slope(Ix, j) = slope array                                   *
c *   phixy(Ix, j) = curvature array                               *
c *                                                                *
c ******************************************************************

      implicit double precision (a-h, o-z)
      common/mats/ d, t, e, fy, tl
      common/defm/  wxy(2,200), rotxy(2,200), wrsu(2,200),
     +              slope(2,200), phixy(2,200)
      common/dent1/ ndent(200), n, nstat
      common/dent/  detl(200), ddent(200), dbeta(200), wint(2,200)
      common/capt/ py, pu, emy, emp, emu, phiy, philb
      common/bound/ nbond, method
      dimension   alph(200)

       do 660 Ix =1, 2
c ##### Calculate alph-bar for curvature distribution #####
       do 670 j = 2, n
       da = phixy(Ix, j-1)
       db = phixy(Ix, j)
       dc = phixy(Ix, j+1)
       h1 = detl(j-1)
       h2 = detl(j)
670    alph(j)  = (da*(h1*h1*h2*(h1 + 2.*h2) - h2**4) + 
     +            db*((h1*h1 + h2*h2)**2 + 6.*h1*h1*h2*h2 +
     +            5.*h2*h1**3 + 5.*h1*h2**3) +
     +            dc*(h1*h2*h2*(h2 + 2.*h1) - h1**4))/
     +            (12.*h1*h2*(h1 + h2))

       da = phixy(Ix, 1)
       db = phixy(Ix, 2)
       dc = phixy(Ix, 3)
       h1 = detl(1)
       h2 = detl(2)
       alph(1)  = (da*h1*h2*(3.*h1 + 4.*h2) + 
     +            db*h1*(h1*h1 + 3.*h1*h2 + 2.*h2*h2) - 
     +            dc*h1*h1*h1)/(12.*h2*(h1 + h2))


       da = phixy(Ix, n-1)
       db = phixy(Ix, n)
       dc = phixy(Ix, n+1)
       h1 = detl(n-1)
       h2 = detl(n)
       alph(n+1)  = (da*h1*h2*(3.*h1 + 4.*h2) + 
     +              db*h1*(h1*h1 + 3.*h1*h2 + 2.*h2*h2) - 
     +              dc*h1*h1*h1)/(12.*h2*(h1 + h2))

c ######     Simply Supported Members  ################## 
c ##### Calculate slope #####

         if (nbond .eq. 100) then
         atot = 0.0
         do 680 jj = 1, n+1
         dleng = 0.0
         do 675 j= jj, n
675      dleng = dleng + detl(j)
680     atot = atot - alph(jj)*dleng
        slope(Ix, 1) = atot/tl + alph(1) 
        do 685 j = 2, n
685     slope(Ix,j) = slope(Ix,j-1) + alph(j)

c ##### calculate deflection #####
        wrsu(Ix, 1) = 0.0
        do 690 j =2, n+1
690     wrsu(Ix, j) = wrsu(Ix, j-1) + slope(Ix, j-1)*detl(j-1)
        endif

c ########   For Cantilever Member  ######################
c ##### Calculate slope #####

         if (nbond .eq. 101) then
         atot = 0.0
         do 110 j = 1, n+1
110     atot = atot + alph(j)
        slope(Ix, 1) = atot - alph(1) 
        do 120 j = 2, n+1
120     slope(Ix,j) = slope(Ix,j-1) - alph(j)

c ##### calculate deflection #####
        wrsu(Ix, n+1) = 0.0
        do 130 j =n, 1, -1
130     wrsu(Ix, j) = wrsu(Ix, j+1) + slope(Ix, j)*detl(j)
        wrsu(Ix, 1) = - wrsu(Ix, 1)*phiy
        endif
        
c ##### Deflection Correction #####
        dy  = wrsu(Ix, n+1)
        dleng = 0.0
        do 695 j = 2, n+1
        dleng = dleng + detl(j-1)
695     wrsu(Ix, j) = - (wrsu(Ix, j) - dleng*dy/tl)*phiy
c ##### Slope Correction #####
        dsp = dy/tl
        do 700 j=1, n+1
700     slope(Ix, j) = - (slope(Ix, j) + dsp)*phiy

660     continue
        do 590 j = 1, n+1
        slope(1,j) = -slope(1,j)
        wrsu(1,j)  = -wrsu(1,j)
590     continue

          return
          end

c ******************************************************************
       subroutine intrup1(nnter)
c ******************************************************************
c *                                                                *
c *   Subroutine intrup1(nnter) is to print the interrupt          *
c *   information when iterations are more than 500 times          *
c *                                                                *
c ******************************************************************

        if (nnter .gt. 10 ) then
        write (6, 50)
50      format('Interrupt !',//,
     +          'Iteration more than 500 times',/,
     +         'Please Change your Input Data for',/,
     +         'Load Ratio Limits and Deflection Incremental!',//,
     +   5x, 'If you did not obtain first step solution',
     +   '  REDUCE minimum  load limit', //,
     +   5x, 'The Most effective way is CHANGE maximum load limit', //,
     +   5x, 'OR  you can try to CHANGE deflection incremental', //,
     +   10x, ' TRY AGAIN,  GOOD LUCK!')

         stop
         endif
         return
         end
         
c ******************************************************************
       subroutine intrup2(wdcu, wdf)
c ******************************************************************
c *                                                                *
c *   Subroutine intrup2(wdcu, wdf) is to print the interrupt      *
c *   information when current computed deflection is less         *
c *   than the last step deflection.                               *
c *                                                                *
c ******************************************************************
 
        implicit double precision (a-h, o-z)  
        if (wdcu .lt. wdf) then
        write (6, 50)
50      format('Interrupt !', //,
     +     'Computed Deflection Less Than Last Step Deflection!', //,
     +        'Please Change your Input Data for',/,
     +        'Load Ratio Limits and Deflection Incremental!',//,
     +  5x, 'The Most effective way is CHANGE maximum load limit', //,
     +  5x, 'You can try to CHANGE deflection incremental ', //,
     +  5x, 'OR you can try to  CHANGE minimum load limit ', //,
     +  10x, ' TRY AGAIN,  GOOD LUCK!')

         stop
         endif
         return
         end


c ******************************************************************  
       subroutine defang(dfxy, dfag, deft,  n)
c ******************************************************************
c *                                                                *
c *   Subroutine defang(dfxy, dfag, deft, n) is to compute the     *
c *   resultant deflection magnitudes  and directional angles.     *
c *                                                                *
c *   dfxy(2, n) = deflection array with respect to                *
c *                  X-X and Y-Y axes                              *
c *   dfag(n)    = directional angle array with respect to         *
c *                X-X axis for resultant deflections              *
c *   deft(n)    = magnitude array of resultant deflections        *
c *                                                                *
c ******************************************************************
 
       implicit double precision (a-h, o-z)
       common/pi/   pi
       common/bound/ nbond, method
       dimension  dfxy(2,200), dfag(200), deft(200)

c ##### Calculate resultant moment magnitude and direction angle #####
       if (nbond .eq. 100)   m = 2 
       if (nbond .eq. 101)  m = 1

       do 100 j = m, n 
       deft(j) = dsqrt( dfxy(1,j)*dfxy(1,j) + dfxy(2,j)*dfxy(2,j) )
        
       if (dfxy(1,j) .eq. 0.0 .and. dfxy(2,j) .eq. 0.0) then
           dfag(j) = 0.0
       elseif (dfxy(1,j) .le. 0.0) then
           dfag(j) = pi - dasin(dfxy(2,j)/deft(j))
       elseif (dfxy(2,j) .gt. 0.0) then
           dfag(j) = dasin(dfxy(2,j)/deft(j))
       else
           dfag(j) = 2.*pi + dasin(dfxy(2,j)/deft(j))
       endif
100    continue
       return
       end 

c ******************************************************************
      subroutine bcdents()
c ******************************************************************
c *                                                                *
c *   Subroutine bcdents() is a simple hinge approach to analyze   *
c *   approximately  the behavior of dented  tubular members       *
c *   subjected to constant lateral loads with an increasing       *
c *   axial load                                                   *
c ******************************************************************

       implicit double precision (a-h, o-z)
       common/mats/ d, t, e, fy, tl
       common/resd1/ ires
       common/resd/  fr1, fr2
       common/bond/ rstax, rstay, rstbx, rstby 
       common/load1/ ip, iemax, iemay
       common/load/  eax, eay, ebx, eby, quax, quay, qubx, quby, 
     +   qcx1, qcy1, zc1, qcx2, qcy2, zc2, emax, emay, embx, emby
       common/capt/ py, pu, emy, emp, emu, phiy, philb
       common/mphd/ emud, empud, phipud, sd
       common/pi/ pi
       common/local/ nloca
       common/bound/ nbond, method
       common/simp/  wintx, winty, bmx, bmy, bmrts, bmags, dangs, 
     +               wdx, wdy, sl, dl, beta, dd, ppmin,ppmax, dphi

       common/down/ ddw, dw1, comstop

        beta = beta*pi/180.
        write( 6, 51)
51      format(//, 3x, 'P/Py', 7x, 'P (N)', 6x,'M/My', 3x,
     +  'Phi/Phiy', 3x, 'Def-X', 5x, 'Def-Y', 5x, 'Short',/,
     +   43x, '(mm)',7x,'(mm)',6x,'(mm)')
c ######### Calculate Deflection under Lateral Loads #########
        p = 0.0
        phic = 0.0
        emom = 0.0
        pc = 0.0
        epsc = 0.0
        call bedms(p)  
        bmrtc = bmrts/2.
        call epsilon(bmrtc, epsc, pc, eps, p)
        if (dd/t .le. 1.0) then
         call mphiud( phic, emom, phid, bmrts, p, phim)
        else
         dangs = theta(bmags, beta)
         call mphidt(phic, emom, dangs, dd, phid, bmrts, p, phim)
        endif
        if (nbond .eq. 101) then
         dwxy = phid*phiy*tl*tl/2.5
c        dwxy = phid*phiy*(dl*(tl-dl/2.) + (tl-dl)*(tl-dl)/3.)
         wdx  =   dwxy*dcos(bmags - pi/2.)
         wdy  =   dwxy*dsin(bmags - pi/2.)
         short1 =  tl - dsqrt(tl*tl - dwxy*dwxy) 
         short2 = eps*tl*fy/e
         short = short1 + short2
        else
c        dwxy = phid*phiy*tl*tl/10.
         dwxy = phid *phiy*dl*(tl - sl - dl/2.)*sl/tl
         sl2 = tl - sl - dl 
         dwxy = dwxy + sl/tl*phid*phiy*(sl/2.*(tl - 2.*sl/3.) +
     +         sl2*sl2/3.) - phid*phiy*sl*sl/6.
         wdx  = - dwxy*dcos(bmags - pi/2.)
         wdy  = - dwxy*dsin(bmags - pi/2.)
         dwxym = dwxy*tl/2./sl
         short1 =  tl - 2.*dsqrt(tl*tl/4.- dwxym*dwxym) 
         short2 = eps*tl*fy/e
         short = short1 + short2
        endif 

        defx = wdx + wintx
        defy = wdy + winty
        pa = p*py
        emt1 = bmrts
        write(6, 52) p, pa, emt1, phid, defx, defy, short
        epsc = eps

c ##############################################################

        pp1 = 0.0
        pp2 = 0.0
        np  = 0

        do 900  m = 1, 10000
        niter  = 0
        nnter  = 0
        psta = ppmin
        pend =  ppmax
        phid  = phid  + dphi
        dphic = dphi
        if (pp1 .lt. pp2) then 
          np = np + 1
          pend = pp1
        endif

        if (np .eq. 1) then
          peak = pp2
          print*, 'Peak Axial Load    P =', peak*py, '  N'
          write(6,304) peak*py
304       format(5x, 'Peak Axial Load    P =', f15.3, 2x,'N')
         endif
        pp2 = pp1
c #####  Determine axial load   #######
        pendp = pend
        pstap = psta

300     p1 = psta + (pend - psta)*0.658
        p  = p1

299     if (nbond .eq. 101) then
c        dwxy = phid*phiy*(dl*(tl-dl/2.) + (tl-dl)*(tl-dl)/3.)
         dwxy = phid*phiy*tl*tl/2.5
         wdx  =   dwxy*dcos(bmags - pi/2.)
         wdy  =   dwxy*dsin(bmags - pi/2.)
         short1 =  tl - dsqrt(tl*tl - dwxy*dwxy) 
        else
c        dwxy = phid*phiy*tl*tl/10.
         dwxy = phid*phiy*dl*(tl - sl - dl/2.)*sl/tl
         sl2 = tl - sl - dl 
         dwxy = dwxy + sl/tl*phid*phiy*(sl/2.*(tl - 2.*sl/3.) +
     +         sl2*sl2/3.) - phid*phiy*sl*sl/6.
         wdx  = - dwxy*dcos(bmags - pi/2.)
         wdy  = - dwxy*dsin(bmags - pi/2.)
         dwxym = dwxy*tl/2./sl
         short1 =  tl - 2.*dsqrt(tl*tl/4.- dwxym*dwxym) 
        endif 

        call bedms(p)
        exterm = bmrts
c ######## Calculate Shortening ####################
        bmrtc = bmrts/2.
        call epsilon(bmrtc, epsc, pc, eps, p)
        short2 = eps*tl*fy/e
        short = short1 + short2
c ###################################################

        if (nnter .gt. 10 ) then
        write (6, 50)
50      format('Interrupt !',//,
     +          'Iteration more than 500 times',/,
     +         'Please Change your Input Data for',/,
     +         'Load Ratio Limits and Curvature Incremental!',//,
     +   5x, 'If you did not obtain first step solution',
     +   '  REDUCE Minimum  Load Limit', //,
     +   5x, 'The Most effective-- REDUCE Curvature Incremental', //,
     +   5x, 'OR  you can try to CHANGE Maximum Load Limit', //,
     +   10x, ' TRY AGAIN,  GOOD LUCK!')

         stop
         endif
         
c ################# Check Iteration Numbers #########
        niter = niter + 1
        if (niter .gt. 50) then
        nnter = nnter + 1
        dphid = 0.5*dphic
        dphic = dphid
        phid = phidd + dphid
        niter = 0
        psta = pstap
        goto 300
        endif

c #####################################################

        if (dd/t .lt. 1.0) then
        call momud(phid, emt, p)
        else
        dangs = theta(bmags, beta)
        call momdt(dangs, dd, p, phid, emt) 
        endif
        termt = emt
         
        dero = exterm - termt
        der1 = abs((exterm - termt)/termt)

        if ( abs(der1) .gt. 0.0001 ) then
          if ( dero .gt. 0.)  then
           pend  = p
          else
           psta = p
          endif
         goto 300
         endif

        phidd = phid
        defx = wdx + wintx
        defy = wdy + winty
        pa = p*py
        emt1 = termt
        pp1 = p
        pc = p
        epsc = eps
        write(6, 52) p, pa, emt1, phid, defx, defy, short
        if (p .lt. comstop*peak) then
        comst = comstop*100.
        write(6, 58) comst
58      format(//,10x, 'Axial Load Less Than ', f4.1, '% Peak Load',
     +    //, 10x, 'Computation Finish, Thank you for your effort',
     +    //, 10x, 'Good Bye!')

        stop
        endif

900     continue
52      format(/,f8.3, e14.4, 2f8.3, 3f10.3) 
        return
        end

c ******************************************************************
      subroutine bedms(p)
c ******************************************************************
c *                                                                *
c *   Subroutine bedms(p) is to compute bending moments at         *
c *   the  critical section  with respect to X-X and Y-Y axes,     *
c *   and magnitude and direction of the resultant  moments        *
c *                                                                *
c * Variables:                                                     *
c *    p   = axial load normalized by Py                           *
c *    ea  = eccentricity of axial load at A-end                   *
c *    eb  = eccentricity of axial load at B-end                   *
c *    qu  = uniform load                                          *
c *    qc  = concentrated load                                     *
c *    zc  = distance from A-end to concentrated load              *
c *   bmx  = bending moments with respect t X-X axis               *
c *   bmy  = bending moments with respect t Y-Y axis               *
c *   bmags  = directional angle  with respect to X-X axis         *
c *            for resultant moment                                *
c *   bmrts  = magnitude of the resultant moment                   *
c *   dangs  = dent directional angle with respect to applied      *
c *            bending moments                                     *
c *                                                                *
c ******************************************************************

       implicit double precision (a-h, o-z)
       common/mats/  d, t, e, fy, tl
       common/load1/ ip, iemax, iemay
       common/load/  eax, eay, ebx, eby, quax, quay, qubx, quby, 
     +   qcx1, qcy1, zc1, qcx2, qcy2, zc2, emax, emay, embx, emby
       common/capt/ py, pu, emy, emp, emu, phiy, philb
       common/bound/ nbond, method
       common/simp/  wintx, winty, bmx, bmy, bmrts, bmags, dangs, 
     +               wdx, wdy, sl, dl, beta, dd, ppmin,ppmax, dphi
       common/pi/    pi

c ##### Calculate reaction at A-end #####
        pn = p*py
        z = sl
c ##### Simply Supported Members ############
       if (nbond .eq. 100) then
      
       vax = (pn*(ebx - eax) - 
     +       (emay - emby))/tl -
     +       quax*tl/2. - (qubx - quax)*tl/6. -
     +       qcx1*(tl - zc1)/tl - qcx2*(tl -zc2)/tl
       vay = (pn*(eby - eay) - 
     +       (embx - emax)) /tl -
     +       quay*tl/2. - (quby - quay)*tl/6. -
     +       qcy1*(tl - zc1)/tl - qcy2*(tl -zc2)/tl

c #####  Calculate Moment at Critical Section  #####
       dz1 = sl - zc1 
       dz2 = sl - zc2
       if (dz1 .lt. 0.0)  dz1 = 0.0
       if (dz2 .lt. 0.0)  dz2 = 0.0
       bmx  = - pn*(eay - winty - wdy ) -
     +          emax  - vay*z - quay*z*z/2. - 
     +          (quby - quay)*z*z*z/(6.*tl) - qcy1*dz1 - qcy2*dz2
       bmy  =   pn*(eax - wintx - wdxx ) -
     +          emay  + vax*z + quax*z*z/2. + 
     +          (qubx - quax)*z*z*z/(6.*tl) + qcx1*dz1 + qcx2*dz2

       endif

c ##### Cantilever Members ##########
       if (nbond .eq. 101) then
      
c #####  Calculate Moments at Critical Section  #####
       dz1 = sl - zc1 
       dz2 = sl - zc2
       if (dz1 .lt. 0.0)  dz1 = 0.0
       if (dz2 .lt. 0.0)  dz2 = 0.0
       wintyd = winty*(tl - sl)/tl
       wintxd = wintx*(tl - sl)/tl
       wdyd = wdy*(tl - sl)/tl
       wdxd = wdx*(tl - sl)/tl
       
       bmx = - pn*(eay + winty + wdy - wintyd - wdyd)
     +       - emax - quay*z*z/2. - 
     +         (quby - quay)*z*z*z/(6.*tl) - qcy1*dz1 - qcy2*dz2
       bmy =   pn*(eax + wintx + wdx - wintxd - wdxd)
     +       - emay + quax*z*z/2. + 
     +         (qubx - quax)*z*z*z/(6.*tl) + qcx1*dz1 + qcx2*dz2

       endif

c ##### Calculate resultant moment magnitude and direction angle #####
       bmrts = sqrt( bmx*bmx + bmy*bmy )
        if (abs(bmx/emy) .lt. 0.001 .and. abs(bmy/emy) .lt. 0.001) then
           bmags = 0.0
        elseif (bmx .le. 0.0) then
           bmags = pi - dasin( bmy/bmrts)
        elseif (bmy .gt. 0.0) then
           bmags = dasin( bmy/bmrts)
        else
           bmags = 2.*pi + dasin( bmy/bmrts)
        endif

        bmrts = bmrts/emy
        bmx   = bmx/emp
        bmy   = bmy/emp
       return 
       end


c ******************************************************************
      subroutine momud( phit, emt, p)
c ******************************************************************
c *                                                                *
c *   Subroutine momud(phit, emt, p) is to compute  moment  for    *
c *   a given curvature and a given axial load  on undented        *
c *   tubular sections                                             *
c *                                                                *
c * Variables:                                                     *
c *    p   = axial load normalized by Py                           *
c *   emt  = bending moment normalized by My                       *
c *   phit = current curvature of segment                          *
c *                                                                *
c ******************************************************************

      implicit double precision (a-h, o-z)
      common/mats/ d, t, e, fy, tl
      common/mtph/ a, b, c, f, em1, em2, empc, phi1, phi2
      common/mphd/ emud, empud, phipud, sd
      common/dscn/ emmin, emmax, eimax
      common/resd1/ ires
      common/resd/  fr1, fr2
      common/pi/ pi 
      common/capt/ py, pu, emy, emp, emu, phiy, philb
      common/local/ nloca

       call resid(p)
c ##### Determine local buckling starting curvature and moment #####
        call mpud(p)
        call abcf(p)
c########
       if (nloca .eq. 1) then
        call descen(p)
        philb = phibck(p)
       if (phit .lt. philb) then

        if (phit .lt. phi1) then
          emt = a*phit
        elseif (phit .ge. phi1 .and. phit .lt. phi2) then
          emt = b - c/sqrt(phit)
        else
         emt = empc - f/(phit*phit)
        endif
        else
         emt = (emmax - emmin)*exp(((phit - philb)*eimax)/
     +         (emmax - emmin)) + emmin
        endif
      else
        if (phit .lt. phi1) then
          emt = a*phit
        elseif (phit .ge. phi1 .and. phit .lt. phi2) then
          emt = b - c/sqrt(phit)
        else
         emt = empc - f/(phit*phit)
        endif
       endif
       return
       end
       

c ******************************************************************
      subroutine momdt(beta,  dd, p,  phit, emt)
c ******************************************************************
c *                                                                *
c *   Subroutine momdt(beta, dd, p, phit, emt ) is to  compute     *
c *   moment  for a given curvature and a given axial load on      *
c *   dented tubular sections                                      *
c *                                                                *
c * Variables:                                                     *
c *    p   = axial load normalized by Py                           *
c *   beta = dent directional angle                                *
c *    dd  = debt depth                                            *
c *   emt  = bending moment normalized by My                       *
c *   phit = computed  curvature of segment                        *
c *    Mud = moment capacity of dented section                     *
c *          normalized by Mp                                      *
c *    Pud = axial yield strength of dented section                *
c *    Sd  = slope function of descending branch                   *
c *                                                                *
c ******************************************************************

      implicit double precision (a-h, o-z)
      common/mats/ d, t, e, fy, tl
      common/mtph/ a, b, c, f, em1, em2, empc, phi1, phi2
      common/mphd/ emud, empud, phipud, sd
      common/resd1/ ires
      common/resd/  fr1, fr2
      common/pi/ pi 
      common/capt/ py, pu, emy, emp, emu, phiy, philb

       call resid(p)
c ##### Determine curvature for a dented section #####

        call mpdt (beta, dd, p)
        call abcf(p)
c ######
       if (phit .lt. phi1) then
         emt = a*phit
       elseif (phit .ge. phi1 .and. phit .lt. phipud) then
         emt = b - c/sqrt(phit)
       else
        emt = empud*(1. - sd*(phit/phipud - 1.))
       endif
       return
       end

c  ############## END OF THE WHOLE PROGRAM #####################
