      PROGRAM DGROUT
C ====================================================================
C
C     DEVELOPERS : PROFESSOR JAMES M. RICLES
C     	           CHIH-PING FAN
C                  LEHIGH UNIVERSITY
C                  DEPARTMENT OF CIVIL & ENVIRONMENTAL ENGINEERING
C     APPROACH   : MOMENT CURVATURE INTEGRATION METHOD FOR ANALYSIS OF
C                  INTERNALLY GROUT REPAIRED DENT-DAMAGED TUBULARS
C     OUTPUT     : 1. MOMENT-CURVATURE RELATIONSHIP AT SELECTED AXIAL LOAD
C                : 2. AXIAL COMPRESSION-SHORTENING RESPONSE
C                  3. AXIAL COMPRESSION-LATERAL DISPLACEMENT RESPONSE
C                  4. FIBER STRAIN
C     VERSION    : 6.3 - Automatic displacement-control algorithm
C                  July 1995
C
C ====================================================================
C ********************************************************************
C     MAIN PROGRAM
C ********************************************************************
      DOUBLE PRECISION UM(300),UPHI(300),DM(300),DPHI(300)
      DOUBLE PRECISION ysave(100),dely(100)
      INTEGER NCOUNTU,NCOUNTD
      CHARACTER*1 LIMIT
      CHARACTER*13 FI,FO
      CHARACTER*72 title(2)
      REAL L
      COMMON /GEO1/L,D_OUTER,D_INNER,T,DD,FY,ES,FG,EU1,fr
      COMMON /GEO2/n_seg,N_DENT,DELTAP,ECC,R,EG
      COMMON /GEO3/P,LK,pmax,pmin,pold
      COMMON /GROUT3D/DM,DPHI,NCOUNTD
      COMMON /GROUT3/UM,UPHI,NCOUNTU
      COMMON /LIMIT/LIMIT
      COMMON /CHESS/NF1,NF2,NF3
      COMMON /CFACTOR/CFAC1,CFAC2,EPSILON,YMAX
      COMMON /iCFACTOR/iCFAC1,iCFAC2,MPH,ilim2
      COMMON /header/title
      COMMON /DES/SHORT_OLD
      common /iprint/nprint
      common /save/ysave,dely_dent
      common /icontrol/ncycle
C
      LIMIT='N'
99    continue
C
C     SPECIFIY INPUT DATA FILE NAME 
C
      write(6,100)
100   format(
     &3x,'              PROGRAM DGROUT',/,
     &3x,'DEVELOPERS : PROFESSOR JAMES M. RICLES,',/,
     &3x,'             CHIH-PING FAN',/,
     &3x,'LEHIGH UNIVERSITY',/,
     &3x,'DEPARTMENT OF CIVIL & ENVIRONMENTAL ENGINEERING',//,
     &3x,'MOMENT CURVATURE INTEGRATION METHOD FOR ANALYSIS OF',/,
     &3x,'INTERNALLY GROUT REPAIRED DENT-DAMAGED TUBULARS.',/,
     &3x,'OUTPUT:'
     &   ' 1. MOMENT-CURVATURE RELATIONSHIP AT SELECTED AXIAL LOAD',/,
     &3x,'        2. AXIAL COMPRESSION-SHORTENING RESPONSE',/,
     &3x,'        3. AXIAL COMPRESSION-LATERAL DISPLACEMENT RESPONSE',/,
     &3x,'        4. FIBER STRAIN',/,
     &3x,'VERSION: 6.3 - July 1995',//,
     &3x, 'Note: The user is responsible for the results obtained.',//,
     &3x,'Enter name of input data file>',$)
      read(5,200) fi
200   format(a13)
      OPEN(1,file=FI,status='old',err=99)
      rewind 1
C
C     SPECIFIY OUTPUT DATA FILE NAME 
C
199   continue
      write(6,300)
300   format(3x,'Enter name of output data file>',$)
      read(5,200) fo
      OPEN(2,file=FO,status='new',err=199)
      rewind 2
C
C     READ INPUT DATA FROM USER SPECIFIED INPUT FILE
C
      CALL READIN
C
C     INITIALIZE VARIABLES
C
      PI=4.0*DATAN(1.0D0)
      DELP=(FG*.25*D_INNER**2*PI+FY*.25*(D_OUTER**2-D_INNER**2)*PI)/
     :NCYCLE
      NCYCLE=NCYCLE-1
      SHORT_OLD = 0.0
C
C     COMPUTE AREA NAD CENTROIDS OF UNDENTED AND DENTED GROUT-FILLED
C     CROSS_SECTION
C
      CALL AREA_UNDENT
      CALL AREA_DENT
C
      WRITE(2,331)' P        AXIAL        LATERAL         FIBER STRAIN
     &       '
      WRITE(2,331)'          SHORTENING   DEFLECTION
     &       '
      WRITE(2,331)'(force)   (length)     (length)       '
      WRITE(2,332)NF1,NF2,NF3
      WRITE(2,*)'-------------------------------------------------------
     &-------'
      WRITE(6,331)' P        AXIAL        LATERAL         FIBER STRAIN
     &       '
      WRITE(6,331)'          SHORTENING   DEFLECTION
     &       '
      WRITE(6,331)'(force)  (length)       (length)  '
      WRITE(6,332)NF1,NF2,NF3
      WRITE(6,*)'-------------------------------------------------------
     &-------'
 331  FORMAT(A62)
 332  FORMAT(39X,I2,7X,I2,7X,I2)
C
C     PERFORM M-P-PHI AND INTEGRATION ANALYSIS
C
C
C     LOAD CONTROL - ASCENDING BRANCH OF RESPONSE 
C
      DO 30 LK=1,NCYCLE
        P=LK*DELP
        if(lk.eq.nprint) then
        write(2,1111) p
1111    format(5x,'M-PHI Relationship at Ascending Axial load =',f8.3)
        endif
        CALL UMPHI
        IF(MPH.LT.0) GO TO 29
        CALL DMPHI
        IF(MPH.LT.0) GO TO 29
        IF(LIMIT.EQ.'Y') GO TO 29
        CALL INTER_GROUT
 29     CONTINUE
        IF(LIMIT.EQ.'Y') THEN
        GOTO 3091
        ENDIF
 30   CONTINUE
C
C       THE ULTIMATE STRENGTH OF INTERNALLY GROUT REPAIRED TUBE HAS
C       BEEN REACHED.  PROCEED TO DESCENDING BRANCH OF RESPONSE  
C
 3091 CONTINUE
      WRITE(6,1500)
 1500 FORMAT(5x,
     & 'THE ULTIMATE STRENGTH OF INTERNALLY GROUT REPAIRED TUBE HAS',/,
     & 5x,'BEEN REACHED.  PROCEED TO DESCENDING BRANCH OF RESPONSE ')
C     INITIALIZE DISPLACEMENT
      DO 35 I=1,n_seg+1
 35   DELY(I)=YSAVE(I)*EPSILON 
      DELY_DENT=DELY(N_DENT+1)
      p=p-delp
 145  CONTINUE
c     SET AXIAL LOAD PARAMETERS FOR DISPLACEMENT CONTROL
      pmax=p
      pmin=0.25*p
      pold=p
      ilim2=0
c     INCREMENT DISPLACEMENT AT CONTROL STATION
      DO 40 I=1,n_seg+1
 40   YSAVE(I)=YSAVE(I) + DELY(I)
      IF(YSAVE(N_DENT+1).GT.YMAX) THEN
        WRITE(6,400)
 400    FORMAT(5X,'NEXT DISPLACEMENT AT CONTROL STATION EXCEEDS MAXIMUM',
     &         ' USER SPECIFIED VALUE FOR YMAX.',/,
     &         5x,' PROGRAM SUCCESSFULLY TERMINATED.')
        GO TO 147
      ENDIF
 146  CONTINUE
      CALL UMPHI
      IF(MPH.LT.0) THEN
        P=0.95*P
        GO TO 146
      ENDIF
      CALL DMPHI
      IF(MPH.LT.0) THEN
        P=0.95*P
        GO TO 146
      ENDIF
        CALL INTER_GROUT_DESCENDING
      IF(MPH.LT.0) THEN
        P=0.95*P
        GO TO 146
      ENDIF
C.... CHECK CONVERGENCE
      IF(LIMIT.EQ.'Y') THEN
C.... PROCEED TO NEXT DISPLACEMENT STEP
        GO TO 145
      ELSE
C.... PROCEED TO CONTINUE ITERATE AT CURRENT CONTROL STATION DISPLACEMENT
C.... WITH NEW LEVEL OF AXIAL LOAD.
        GO TO 146
      ENDIF
 147  CONTINUE
      STOP
      END
C --------------------------------------------------------------------
      SUBROUTINE READIN
C
C     Read input data from user specified data file and echo print
C
C --------------------------------------------------------------------
      REAL L
      CHARACTER*72 title(2)
      COMMON /GEO1/L,D_OUTER,D_INNER,T,DD,FY,ES,FG,EU1,fr
      COMMON /GEO2/n_seg,N_DENT,DELTAP,ECC,R,EG
      COMMON /BISECT/BOUND
      COMMON /GROUT1/NS1,NS2,NS3
      COMMON /GROUT1D/NS1D,NS2D,NS3D
      COMMON /CFACTOR/CFAC1,CFAC2,EPSILON,YMAX
      COMMON /iCFACTOR/iCFAC1,iCFAC2,MPH,ilim2
      COMMON /DESTOR/ALPHA,SMALL_N,BETA,GAMMA
      COMMON /CHESS/NF1,NF2,NF3
      COMMON /header/title
      common /iprint/nprint
      common /icontrol/ncycle
      READ(1,*)
      READ(1,100) title(1)
      READ(1,100) title(2)
      READ(1,*)
      READ(1,*)L
      READ(1,*)
      READ(1,*)D_OUTER
      READ(1,*)
      READ(1,*)T
      READ(1,*)
      READ(1,*)DD
      READ(1,*)
      READ(1,*)FY
      READ(1,*)
      READ(1,*)ES
      READ(1,*)
      READ(1,*)FG
      READ(1,*)
      READ(1,*)FR
      READ(1,*)
      READ(1,*)EG
      EU1=2.*FG/EG
      D_INNER=D_OUTER-2.*T
      READ(1,*)
      READ(1,*)n_seg
      IF(n_seg.GT.99) THEN
       WRITE(6,135) 
 135   FORMAT(5x,'*** Number of segments cannot exceed 99 - '
     &          ' Program terminated')
      ENDIF
      READ(1,*)
      READ(1,*)N_DENT
      READ(1,*)
      READ(1,*)NS1D,NS2D,NS3D
      NTOTAL=NS1D+NS2D+NS3D
      IF(NTOTAL.GT.100) THEN
       WRITE(6,137)
 137   FORMAT(
     &5x,'*** Number of total dented cross-section layers cannot',
     &   ' exceed 100 - Program terminated.')
       ENDIF
      READ(1,*)
      READ(1,*)NS1,NS2,NS3
      NTOTAL=NS1+NS2+NS3
      IF(NTOTAL.GT.100) THEN
       WRITE(6,138)
 138   FORMAT(
     &5x,'*** Number of total undented cross-section layers cannot'
     &   ' exceed 100 -',
     &5x,'    Program terminated.')
       ENDIF
      READ(1,*)
      READ(1,*)ECC
      READ(1,*)
      READ(1,*)R
      READ(1,*)
      READ(1,*)ICFAC1,ICFAC2
      READ(1,*)
      READ(1,*)CFAC1,CFAC2,YMAX
      READ(1,*)
      READ(1,*)NCYCLE
      READ(1,*)
      READ(1,*)EPSILON
      READ(1,*)
      READ(1,*)DELTAP
      READ(1,*)
      READ(1,*)ALPHA,SMALL_N,BETA,GAMMA
      SMALL_N=ABS(SMALL_N)
      READ(1,*)
      READ(1,*)NF1,NF2,NF3
      READ(1,*)
      READ(1,*)BOUND
      READ(1,*)
      READ(1,*)NPRINT
      READ(1,*)
C
C     ECHO PRINT INPUT DATA
C
      WRITE(6,100) title(1)
      WRITE(6,100) title(2)
      WRITE(2,100) title(1)
      WRITE(2,100) title(2)
      WRITE(6,105)
      WRITE(2,105)
      WRITE(6,110) L,D_OUTER,T,DD
      WRITE(2,110) L,d_outer,t,dd
      WRITE(6,120) FY,ES,FG,EG,FR
      WRITE(2,120) fy,es,fg,eg,fr
      WRITE(6,130) n_seg,N_DENT,NS1D,NS2D,NS3D
      WRITE(2,130) n_seg,n_dent,ns1d,ns2d,ns3d
      WRITE(6,140) ECC,R
      WRITE(2,140) ecc,r
      WRITE(6,150) ICFAC1,ICFAC2,CFAC1,CFAC2,YMAX,NCYCLE
      WRITE(2,150) icfac1,icfac2,cfac1,cfac2,ymax,ncycle
      WRITE(6,160) EPSILON,DELTAP,ALPHA,SMALL_N,BETA,GAMMA
      WRITE(2,160) EPSILON,deltap,alpha,small_n,beta,gamma
      WRITE(6,170) NF1,NF2,NF3,BOUND,NPRINT
      WRITE(2,170) nf1,nf2,nf3,bound,nprint
100   FORMAT(a72)
105   FORMAT(5x,'Echo print of input data',/)
110   FORMAT(5x,'L =',f8.3,3x,'D_OUTER =',f8.3,
     & 3x,'T =',f8.3,3x,'DD =',f8.3)
120   FORMAT(5x,'FY =',f8.3,3x,'ES =',f11.3,
     &  3x,'FG =',f8.3,3x,'EG =',f11.3,3x,'FR =',f8.3)
130   FORMAT(5x,'n_seg =',i3,3x,'n_dent =',i3,3x,'NS1D =',i3,
     &  3x,'NS2D =',i3,3x,'NS3D =',i3)
140   FORMAT(5x,'ECC =',f8.3,3x,'R =',f8.3)
150   FORMAT(5x,'ICFAC1 =',i5,3x,'ICFAC2 =',i5,3x,'CFAC1 =',f8.3,
     &  3x,'CFAC2 =',f8.3,3x,/,5x,'YMAX =',f8.3,
     &  3x,'NCYCLE =',i5)
160   FORMAT(5x,'EPSILON =',f8.3,3x,'DELTAP =',f8.5,/,
     &       5x,'ALPHA =',f8.3,3x,'N =',f8.3,
     &       3x,'BETA =',f8.3,3x,'GAMMA =',f8.3)
170   FORMAT(5x,'NF1 =',i3,3x,'NF2 =',i3,3x,'NF3 =',i3,/,
     &  5x,'BOUND =',f8.3,5x,'NPRINT =',i3)
      RETURN
      END
C --------------------------------------------------------------------
      SUBROUTINE AREA_UNDENT
C
C     Divides undented grout filled cross-section into layers,
C     and determines area and centroid of each layer.
C
C --------------------------------------------------------------------
      DOUBLE PRECISION GAREA(100),SAREA(100),YMEAN(100)
      REAL L
      COMMON /GEO1/L,D_OUTER,D_INNER,T,DD,FY,ES,FG,EU1,fr
      COMMON /GROUT1/NS1,NS2,NS3
      COMMON /GROUT2/YMEAN,GAREA,SAREA
      NTOTAL=NS1+NS2+NS3
      T1=T/float(NS1)
      T2=(D_OUTER-2.*T)/float(NS2)
      T3=T/float(NS3)
      DO 10 I=1,NTOTAL
         IF(I.LE.NS1) THEN
           YUP=D_OUTER/2.-float(I-1)*T1
           YDOWN=D_OUTER/2.-float(I)*T1
           YMEAN(I)=0.5*(YUP+YDOWN)
           XMEAN=SQRT((D_OUTER/2.)**2-YMEAN(I)**2)
           SAREA(I)=2.*XMEAN*T1
           GAREA(I)=0.0
         ELSE IF(I.LE.(NS1+NS2)) THEN
           YUP=D_OUTER/2.-float(NS1)*T1-float(I-NS1-1)*T2
           YDOWN=D_OUTER/2.-float(NS1)*T1-float(I-NS1)*T2
           YMEAN(I)=0.5*(YUP+YDOWN)
           XMEAN=SQRT((D_OUTER/2.)**2-YMEAN(I)**2)
           XMEANI=SQRT((D_INNER/2.)**2-YMEAN(I)**2)
           GAREA(I)=2.*XMEANI*T2
           SAREA(I)=2.*XMEAN*T2-GAREA(I)
         ELSE
           YUP=-D_INNER/2.-float(I-NS1-NS2-1)*T3
           YDOWN=-D_INNER/2.-float(I-NS1-NS2)*T3
           YMEAN(I)=0.5*(YUP+YDOWN)
           XMEAN=SQRT((D_OUTER/2)**2-YMEAN(I)**2)
           SAREA(I)=2.*XMEAN*T3
           GAREA(I)=0.0
         ENDIF
 10   CONTINUE
c
      RETURN
      END
C --------------------------------------------------------------------
      SUBROUTINE AREA_DENT
C
C     Divides dented grout filled cross-section into layers,
C     and determines area and centroid of each layer.
C
C --------------------------------------------------------------------
      DOUBLE PRECISION GAREAD(100),SAREAD(100),YMEAND(100)
      REAL L
      COMMON /GEO1/L,D_OUTER,D_INNER,T,DD,FY,ES,FG,EU1,fr
      COMMON /GROUT1D/NS1D,NS2D,NS3D
      COMMON /GROUT2D/YMEAND,GAREAD,SAREAD
      NTOTALD=NS1D+NS2D+NS3D
      T1D=T/float(NS1D)
      T2D=((D_OUTER-2.*T)-DD)/float(NS2D)
      T3D=T/float(NS3D)
      area_s=0.0
      DO 20 I=1,NTOTALD
         IF(I.LE.NS1D) THEN
           YUPD=D_OUTER/2.-float(I-1)*T1D-DD
           YDOWND=D_OUTER/2.-float(I)*T1D-DD
           YMEAND(I)=0.5*(YUPD+YDOWND)
           XMEAND=SQRT((D_OUTER/2.)**2-YMEAND(I)**2)
           SAREAD(I)=2.*XMEAND*T1D
           GAREAD(I)=0.0
           area_s = area_s + saread(i)
         ELSE IF(I.LE.(ns1d+ns2d)) THEN
           YUPD=D_OUTER/2.-float(NS1D)*T1D-float(I-NS1D-1)*T2D-DD
           YDOWND=D_OUTER/2.-float(NS1D)*T1D-float(I-NS1D)*T2D-DD
           YMEAND(I)=0.5*(YUPD+YDOWND)
           XMEAND=SQRT((D_OUTER/2.)**2-YMEAND(I)**2)
           XMEANID=SQRT((D_INNER/2.)**2-YMEAND(I)**2)
           GAREAD(I)=2.*XMEANID*T2D
           SAREAD(I)=2.*XMEAND*T2D-GAREAD(I)
           area_s = area_s + saread(i)
         ELSE
           YUPD=-D_INNER/2.- float(I-NS1D-NS2D-1.)*T3D
           YDOWND=-D_INNER/2.- float(I-NS1D-NS2D)*T3D
           YMEAND(I)=0.5*(YUPD+YDOWND)
           XMEAND=SQRT((D_OUTER/2.)**2-YMEAND(I)**2)
           SAREAD(I)=2.*XMEAND*T3D
           GAREAD(I)=0.0
           area_s=area_s + saread(i)
         ENDIF
 20   CONTINUE
c     correct to maintain steel area
      pi=atan(1.0)*4.0 
      error_s=pi*t*(d_outer + d_inner)*0.5 - area_s
      area_cor=error_s/float(ns1d)
      do 30 i=1,ns1d
 30   saread(i) = saread(i) + area_cor
      RETURN
      END
C --------------------------------------------------------------------
      SUBROUTINE DMPHI
C
C     Compute moment-curvature relationship for dented, grouted
C     cross-section for specified level of compressive axial load
C
C --------------------------------------------------------------------
      DOUBLE PRECISION GAREAD(100),SAREAD(100),YMEAND(100)
      DOUBLE PRECISION PHI,TOTALP,TOTALM,MMAX
      DOUBLE PRECISION AIN(100),FORCE(100),NA
      DOUBLE PRECISION DM(300),DPHI(300)
      DOUBLE PRECISION STRAIND(300)
      DOUBLE PRECISION SC1(300),SC2(300),SC3(300)
      INTEGER NCOUNTD
      CHARACTER*1 LIMIT
      REAL L
      COMMON /GEO1/L,D_OUTER,D_INNER,T,DD,FY,ES,FG,EU1,fr
      COMMON /GEO2/n_seg,N_DENT,DELTAP,ECC,R,EG
      COMMON /BISECT/BOUND
      COMMON /GEO3/P,LK,pmax,pmin,pold
      COMMON /GROUT1D/NS1D,NS2D,NS3D
      COMMON /GROUT2D/YMEAND,GAREAD,SAREAD
      COMMON /GROUT3D/DM,DPHI,NCOUNTD
      COMMON /AXIAL1/STRAIND
      COMMON /CFACTOR/CFAC1,CFAC2,EPSILON,YMAX
      COMMON /iCFACTOR/iCFAC1,iCFAC2,MPH,ilim2
      COMMON /INVES/SC1,SC2,SC3
      COMMON /CHESS/NF1,NF2,NF3
      COMMON /DESTOR/ALPHA,SMALL_N,BETA,GAMMA
      common /iprint/nprint
      COMMON /LIMIT/LIMIT
C
      NTOTALD=NS1D+NS2D+NS3D
      EY=FY/ES
      MMAX=0.0
      NCOUNTD=0
      MPH=0
      DO 996 K2=2,101
      ilim=0
      PHI=0.0001*FLOAT(K2-1)
      far1=0.0
      far2=bound
 7007 far3=0.5*(far1+far2)
      na=far3
c
C     COMPUTE STRESS RESULTANT FOR EACH LAYER FOR CURRENT CURVATURE PHI
C     AND ASSUMMED POSITION OF NEUTRAL AXIS.
C
      DO 120 I3=1,NTOTALD
        AIN(I3)=(YMEAND(I3)-(0.5*D_OUTER-DD-NA))*PHI
C
C     Compressive Strain
C
        IF(AIN(I3).GE.0.) THEN
        eupper=eu1*(1.0 + alpha)
        ebuck = ey*(1.0 + gamma)
C
C        FOR STEEL
C
         IF(AIN(I3).GE.EY.AND.AIN(I3).LT.EBUCK) THEN
           FOR_S=EY*ES*SAREAD(I3)
         ELSEIF(ain(i3).gt.ebuck) then
           for_s=saread(i3)*fy*(ain(i3)/ebuck)**(-1.0*small_n)
         ELSE
           FOR_S=AIN(I3)*ES*SAREAD(I3)
         ENDIF
C
C        FOR GROUT
C
         IF(AIN(I3).LE.EU1) THEN
           FOR_G=FG*(AIN(I3)/EU1)*(2.0-AIN(I3)/EU1)*GAREAD(I3)
         ELSEIF(ain(i3).gt.eupper) then
           for_g = (fg - beta*(ain(i3) - eupper))*garead(i3)
           if(for_g.lt.0.0) for_g=0.0
         else
           FOR_G=FG*GAREAD(I3)
         ENDIF
C
        ELSE
C
C       Tensile Strain
C
C        FOR STEEL
C
         IF((ABS(AIN(I3))).GE.EY) THEN
           FOR_S=-FY*SAREAD(I3)
         ELSE
           FOR_S=AIN(I3)*ES*SAREAD(I3)
         ENDIF
C
C        FOR GROUT
C
         TEMP=AIN(I3)*EG
         IF(ABS(TEMP).GT.fr) THEN
           FOR_G=-fr*garead(i3)
         ELSE
           FOR_G=TEMP*GAREAD(I3)
         ENDIF
        ENDIF
        FORCE(I3)=FOR_G+FOR_S
 120  CONTINUE
C
C     CHECK CONVERGENCE 
C
      TOTALP=0.
      DO 1270 I9=1,NTOTALD
          TOTALP=TOTALP+FORCE(I9)
 1270 CONTINUE
      IF(ABS(TOTALP-P).LT.P/CFAC1) THEN
      TOTALM=0.0
      DO 1280 I8=1,NTOTALD
        TOTALM=TOTALM+YMEAND(I8)*FORCE(I8)
 1280 CONTINUE
      IF(TOTALM.GT.MMAX) THEN
        MMAX=TOTALM
      ENDIF
      NCOUNTD=NCOUNTD+1
      DM(NCOUNTD)=TOTALM
      DPHI(NCOUNTD)=PHI
      STRAIND(NCOUNTD)=(NA-D_OUTER/2.+DD)*PHI
      SC1(NCOUNTD)=(YMEAND(NF1)-(D_OUTER/2.-DD-NA))*PHI
      SC2(NCOUNTD)=(YMEAND(NF2)-(D_OUTER/2.-DD-NA))*PHI
      SC3(NCOUNTD)=(YMEAND(NF3)-(D_OUTER/2.-DD-NA))*PHI
C
C...  Print out Phi-Moment relationship at user selected axial load
C
      IF(LIMIT.NE.'Y'.AND.NPRINT.EQ.LK) THEN
          write(2,1111)phi,totalm
      ENDIF
1111  format(5x,e11.4,2x,f9.4)
c...
      GOTO 996
      else
        if(ilim.ge.icfac1) then
        write(6,100) icfac1,p,phi
 100    format(
     &5x,'***Non-convergence in DMPHI, icfac1=',i5,5x,'P=',e11.4,
     &2x 'Phi=',e11.4,/,
     &5x,'   Analysis will attempt to proceed')
           if(mmax-dm(ncountd)) 105,105,106
 105       continue
c    Descending branch of M-P-Phi not computed - Analysis will terminate
           WRITE(6,110)
 110       FORMAT(5X,'Peak moment not'
     &5x' achieved in M-PHI during iteration in DMPHI -',
     &  ' Execution terminated')
           STOP
 106       continue
c    Descending branch of M-P-Phi successfully computed - Analysis will continue
           return
        endif
        ilim=ilim+1
        if(totalp.gt.p) then
          far1=far1
          far2=far3
        else
          far1=far3
          far2=far2
        endif
        goto 7007
      ENDIF
 996  CONTINUE
      RETURN
      END
C --------------------------------------------------------------------
      SUBROUTINE UMPHI
C
C     Compute moment-curvature relationship for undented, grouted
C     cross-section for specified level of compressive axial load
C
C --------------------------------------------------------------------
      DOUBLE PRECISION PHI,TOTALP,TOTALM,MMAX
      DOUBLE PRECISION GAREA(100),SAREA(100),YMEAN(100)
      DOUBLE PRECISION AIN(100),FORCE(100),NA
      DOUBLE PRECISION UM(300),UPHI(300)
      DOUBLE PRECISION STRAINU(300)
      INTEGER NCOUNTU
      REAL L
      COMMON /GEO1/L,D_OUTER,D_INNER,T,DD,FY,ES,FG,EU1,fr
      COMMON /GEO2/n_seg,N_DENT,DELTAP,ECC,R,EG
      COMMON /BISECT/BOUND
      COMMON /GEO3/P,LK,pmax,pmin,pold
      COMMON /GROUT1/NS1,NS2,NS3
      COMMON /GROUT2/YMEAN,GAREA,SAREA
      COMMON /GROUT3/UM,UPHI,NCOUNTU
      COMMON /AXIAL2/STRAINU
      COMMON /CFACTOR/CFAC1,CFAC2,EPSILON,YMAX
      COMMON /DESTOR/ALPHA,SMALL_N,BETA,GAMMA
      COMMON /iCFACTOR/iCFAC1,iCFAC2,MPH,ilim2
C
      NTOTAL=NS1+NS2+NS3
      EY=FY/ES
      MMAX=0.0
      MPH=0
      NCOUNTU=0
      DO 881 KK=2,100
       PHI=0.000025*FLOAT(KK-1)
       ilim=0
       far1=0.0
       far2=bound
 8008  far3=0.5*(far1+far2)
       na=far3
c
C     COMPUTE STRESS RESULTANT FOR EACH LAYER FOR CURRENT CURVATURE PHI
C     AND ASSUMMED POSITION OF NEUTRAL AXIS.
C
      DO 126 I3=1,NTOTAL
        AIN(I3)=(YMEAN(I3)-(0.5*D_OUTER-NA))*PHI
C 
C    Compressive Strain
C
        IF(AIN(I3).GE.0.) THEN
        eupper = eu1*(1.0 + alpha)
        ebuck = ey*(1.0 + gamma)
C
C        FOR STEEL
C
         IF(AIN(I3).GE.EY.AND.AIN(I3).LT.EBUCK) THEN
           FOR_S=FY*SAREA(I3)
         ELSEIF(ain(i3).gt.ebuck) then
           for_s=sarea(i3)*fy*(ain(i3)/ebuck)**(-1.0*small_n)
         ELSE
           FOR_S=AIN(I3)*ES*SAREA(I3)
         ENDIF
C
C        FOR GROUT
C
         IF(AIN(I3).LE.EU1) THEN
           FOR_G=FG*(AIN(I3)/EU1)*(2.0-AIN(I3)/EU1)*GAREA(I3)
         ELSEIF (AIN(i3).gt.eupper) then
           for_g = (fg - beta*(ain(i3)-eupper))*garea(i3)
           if(for_g.lt.0.0) for_g=0.0
         else
           FOR_G=FG*GAREA(I3)
         ENDIF
        ELSE
C
C       Tensile Strain
C
C        FOR STEEL
C
         IF((ABS(AIN(I3))).GE.EY) THEN
           FOR_S=-FY*SAREA(I3)
         ELSE
           FOR_S=AIN(I3)*ES*SAREA(I3)
         ENDIF
C
C        FOR GROUT
C
         TEMP=AIN(I3)*EG
         IF(ABS(TEMP).GT.fr) THEN
           FOR_G=-fr*garea(i3)
         ELSE
           FOR_G=TEMP*GAREA(I3)
         ENDIF
        ENDIF
        FORCE(I3)=FOR_G+FOR_S
 126  CONTINUE
C
C     CHECK CONVERGENCE
C
      TOTALP=0.
      DO 127 I4=1,NTOTAL
          TOTALP=TOTALP+FORCE(I4)
 127  CONTINUE
      IF(ABS(TOTALP-P).LT.P/CFAC1) THEN
      TOTALM=0.0
      DO 128 I5=1,NTOTAL
        TOTALM=TOTALM+YMEAN(I5)*FORCE(I5)
 128  CONTINUE
      IF(TOTALM.GT.MMAX) THEN
        MMAX=TOTALM
      ENDIF
      NCOUNTU=NCOUNTU+1
      UM(NCOUNTU)=TOTALM
      UPHI(NCOUNTU)=PHI
      STRAINU(NCOUNTU)=(NA-D_OUTER/2)*PHI
      GOTO 881
      else
        if(ilim.ge.icfac1) then
        write(6,100) icfac1,p,phi
 100    format(
     &5x,'***Non-convergence in UMPHI, icfac1=',i5,5x,'P=',e11.4,
     &2x 'Phi=',e11.4,/,
     &5x,'   Analysis will attempt to proceed')
           if(mmax-um(ncountu)) 105,105,106
 105       continue
c    Descending branch of M-P-Phi not computed - Analysis will terminate
           WRITE(6,110)
 110       FORMAT(5X,'Warning: Peak moment not'
     &5x' achieved in M-PHI during iteration in UMPHI - ',/,
     &5x'May lead to premature failure.')
 106       continue
c    Descending branch of M-P-Phi successfully computed - Analysis will continue
           return
        endif
        ilim=ilim+1
        if(totalp.gt.p) then
          far1=far1
          far2=far3
        else
          far1=far3
          far2=far2
        endif
        goto 8008
      ENDIF
 881  CONTINUE
      RETURN
      END
C --------------------------------------------------------------------
      SUBROUTINE INTER_GROUT
C
C     Performs Newmark integration analysis to establish the solution
C     for the displaced shape for current axial load. Load-deflection
C     response is on ascending branch.
C
C --------------------------------------------------------------------
      DOUBLE PRECISION GAREA(100),SAREA(100),YMEAN(100)
      DOUBLE PRECISION GAREAD(100),SAREAD(100),YMEAND(100)
      DOUBLE PRECISION YINI(100),Y(100),PHI(100)
      DOUBLE PRECISION THETA(100),YCAL(100),YSAVE(100)
      DOUBLE PRECISION X(100)
      DOUBLE PRECISION MOMENT,M0
      DOUBLE PRECISION UM(300),UPHI(300)
      DOUBLE PRECISION DM(300),DPHI(300)
      DOUBLE PRECISION STRAIND(300),STRAINU(300)
      DOUBLE PRECISION STRAINDU(100)
      DOUBLE PRECISION SC1(300),SC2(300),SC3(300)
      DOUBLE PRECISION SCC1(100),SCC2(100),SCC3(100)
      INTEGER NCOUNTU,NCOUNTD
      CHARACTER*1 LIMIT
      REAL L
      COMMON /INVES/SC1,SC2,SC3
      COMMON /GEO1/L,D_OUTER,D_INNER,T,DD,FY,ES,FG,EU1,fr
      COMMON /GEO2/n_seg,N_DENT,DELTAP,ECC,R,EG
      COMMON /GEO3/P,LK,pmax,pmin,pold
      COMMON /GROUT1D/NS1D,NS2D,NS3D
      COMMON /GROUT2D/YMEAND,GAREAD,SAREAD
      COMMON /GROUT3D/DM,DPHI,NCOUNTD
      COMMON /GROUT1/NS1,NS2,NS3
      COMMON /GROUT2/YMEAN,GAREA,SAREA
      COMMON /GROUT3/UM,UPHI,NCOUNTU
      COMMON /AXIAL1/STRAIND
      COMMON /AXIAL2/STRAINU
      COMMON /AXIAL3/STRAINDU
      COMMON /CFACTOR/CFAC1,CFAC2,EPSILON,YMAX
      COMMON /iCFACTOR/iCFAC1,iCFAC2,MPH,ilim2
      COMMON /LIMIT/LIMIT
      COMMON /ASTR1/SCC1,SCC2,SCC3
      common /save/ysave,dely_dent
      LIMIT='N'
      PI=4.0*DATAN(1.0D0)
      D_AVG=0.5*(D_INNER+D_OUTER)
      SORI=P/(ES*(PI*D_AVG*T+(0.25*PI*D_INNER**2)/(ES/EG)))
      DELTAX=L/FLOAT(n_seg)
      DO 122 J1=1,n_seg+1
         X(J1)=DELTAX*FLOAT(J1-1)
         YINI(J1)=DELTAP*L*SIN(PI*X(J1)/L)
         Y(J1)=0.0
 122  CONTINUE
      M0=P*ECC
      ilim=0
C
C     Compute curvature and strain at selected layers and at
C     centroid of cross-section for computed moment
C
 221  DO 124 I1=1,n_seg+1
            MOMENT=M0-((M0+M0/R)/L)*X(I1)+P*(YINI(I1)+Y(I1))
          IF((I1.EQ.N_DENT).OR.(I1.EQ.N_DENT+1)) THEN
            DO 346 KH=1,NCOUNTD
               IF((MOMENT.LE.DM(KH)).AND.(KH.EQ.1)) THEN
                PHI(I1)=DPHI(KH)*MOMENT/DM(KH)
                STRAINDU(I1)=SORI+PHI(I1)*(STRAIND(KH)-SORI)/DPHI(KH)
                SCC1(I1)=SORI+PHI(I1)*(SC1(KH)-SORI)/DPHI(KH)
                SCC2(I1)=SORI+PHI(I1)*(SC2(KH)-SORI)/DPHI(KH)
                SCC3(I1)=SORI+PHI(I1)*(SC3(KH)-SORI)/DPHI(KH)
                GOTO 124
               ELSE IF((MOMENT.LE.DM(KH)).AND.(KH.GT.1)) THEN
                PHI(I1)=DPHI(KH-1)+(DPHI(KH)-DPHI(KH-1))*
     &          ((MOMENT-DM(KH-1))/(DM(KH)-DM(KH-1)))
                STRAINDU(I1)=STRAIND(KH-1)+(PHI(I1)-DPHI(KH-1))*
     &          ((STRAIND(KH)-STRAIND(KH-1))/
     &          (DPHI(KH)-DPHI(KH-1)))
                SCC1(I1)=SC1(KH-1)+(PHI(I1)-DPHI(KH-1))*
     &          ((SC1(KH)-SC1(KH-1))/(DPHI(KH)-DPHI(KH-1)))
                SCC2(I1)=SC2(KH-1)+(PHI(I1)-DPHI(KH-1))*
     &          ((SC2(KH)-SC2(KH-1))/(DPHI(KH)-DPHI(KH-1)))
                SCC3(I1)=SC3(KH-1)+(PHI(I1)-DPHI(KH-1))*
     &          ((SC3(KH)-SC3(KH-1))/(DPHI(KH)-DPHI(KH-1)))
                GOTO 124
               ELSE IF(KH.EQ.NCOUNTD) THEN
C     Segment moment exceeds maximum moment in M-P-Phi Relationship for
C     given axial load, indicating that tubular has reached Pmax.
                LIMIT='Y'
                GOTO 567
               ENDIF
 346        CONTINUE
          ELSE
            DO 746 KHK=1,NCOUNTU
               IF((MOMENT.LE.UM(KHK)).AND.(KHK.EQ.1)) THEN
                PHI(I1)=UPHI(KHK)*MOMENT/UM(KHK)
                STRAINDU(I1)=SORI+(STRAINU(KHK)-SORI)*PHI(I1)/UPHI(KHK)
                GOTO 124
               ELSE IF((MOMENT.LE.UM(KHK)).AND.(KHK.GT.1)) THEN
                PHI(I1)=UPHI(KHK-1)+(UPHI(KHK)-UPHI(KHK-1))*
     &          ((MOMENT-UM(KHK-1))/(UM(KHK)-UM(KHK-1)))
                STRAINDU(I1)=STRAINU(KHK-1)+(PHI(I1)-UPHI(KHK-1))*
     &          ((STRAINU(KHK)-STRAINU(KHK-1))/(UPHI(KHK)-UPHI(KHK-1)))
                GOTO 124
               ELSE IF(KHK.EQ.NCOUNTU) THEN
C     Computed moment exceeds maximum moment in M-P-Phi Relationship
               write(6,700)
 700           FORMAT(5x,'Computed moment exceeds maximum moment ',
     &                   'in M-P-Phi Undented Relationship.')
c     &                   'in M-P-Phi Undented Relationship.',/,
c     &       5x,'Program terminated - DGROUT currently developed',/,
c     &       5x,'to respond only to dented segment developing failure.') 
c               stop
               LIMIT='Y'
               GO TO 567
               ENDIF
 746        CONTINUE
          ENDIF
 124  CONTINUE
C --------------------------------------------------------------------
C     ROTATION FORMULATION
C --------------------------------------------------------------------
      THETA(1)=0.
      DO 290 IS=2,n_seg+1
           THETA(IS)=THETA(IS-1)-DELTAX*0.5*(PHI(IS)+PHI(IS-1))
 290  CONTINUE
C --------------------------------------------------------------------
C     CALCULATION OF THE TRIAL DEFLECTIONS
C --------------------------------------------------------------------
      YCAL(1)=0.
      DO 291 IT=2,n_seg+1
        YCAL(IT)=YCAL(IT-1)+THETA(IT-1)*DELTAX-(2.0*PHI(IT-1)+PHI(IT))*
     &  (DELTAX**2/6.0)
 291  CONTINUE
C --------------------------------------------------------------------
C     LINEAR CORRECTION TO SATISFY THE BOUNDARY CONDITION AT THE END
C --------------------------------------------------------------------
      DO 237 IU=1,n_seg+1
         YCAL(IU)=YCAL(IU)-YCAL(n_seg+1)*X(IU)/L
 237  CONTINUE
C --------------------------------------------------------------------
C     CHECK THE CONVERGENCE OF n_seg+1 STATIONS
C --------------------------------------------------------------------
         ilim=ilim+1
      DO 1732 ITEST=1,n_seg+1
      IF(ABS(YCAL(ITEST)-Y(ITEST)).GT.(ABS(YCAL(ITEST)/CFAC2))) THEN
         DO 488 IH=1,n_seg+1
            Y(IH)=YCAL(IH)
 488     CONTINUE
           if(ilim.ge.icfac2) then
           write(6,100) icfac2
 100  format(5x,
     & '***Non-convergence in INTER_GROUT after',i5,' iterations',/,
     & 5x,'   Program terminated')
           stop
           endif
         GOTO 221
       ENDIF
 1732 CONTINUE
c     save last converged lateral displacement profile
      do 1750 i=1,n_seg+1
      ysave(i)=ycal(i)
1750  continue
C     Compute axial shortening
      CALL SHORTENING_GROUT(YCAL)
 567  RETURN
      END
C --------------------------------------------------------------------
      SUBROUTINE INTER_GROUT_DESCENDING
C
C     Performs Newmark integration analysis to establish the solution
C     for the displaced shape for current axial load and specified displacement
C     at the control station. Load-deflection response is on descending branch.
C
C --------------------------------------------------------------------
      DOUBLE PRECISION GAREA(100),SAREA(100),YMEAN(100)
      DOUBLE PRECISION GAREAD(100),SAREAD(100),YMEAND(100)
      DOUBLE PRECISION YINI(100),Y(100),PHI(100),YSAVE(100)
      DOUBLE PRECISION THETA(100),YCAL(100),ytemp(100),X(100)
      DOUBLE PRECISION MOMENT,M0
      DOUBLE PRECISION UM(300),UPHI(300)
      DOUBLE PRECISION DM(300),DPHI(300)
      DOUBLE PRECISION STRAIND(300),STRAINU(300),STRAINDU(100)
      DOUBLE PRECISION SC1(300),SC2(300),SC3(300)
      DOUBLE PRECISION SCC1(100),SCC2(100),SCC3(100)
      INTEGER NCOUNTU,NCOUNTD
      CHARACTER*1 LIMIT
      REAL L
      COMMON /INVES/SC1,SC2,SC3
      COMMON /GEO1/L,D_OUTER,D_INNER,T,DD,FY,ES,FG,EU1,fr
      COMMON /GEO2/n_seg,N_DENT,DELTAP,ECC,R,EG
      COMMON /GEO3/P,LK,pmax,pmin,pold
      COMMON /GROUT1D/NS1D,NS2D,NS3D
      COMMON /GROUT2D/YMEAND,GAREAD,SAREAD
      COMMON /GROUT3D/DM,DPHI,NCOUNTD
      COMMON /GROUT1/NS1,NS2,NS3
      COMMON /GROUT2/YMEAN,GAREA,SAREA
      COMMON /GROUT3/UM,UPHI,NCOUNTU
      COMMON /AXIAL1/STRAIND
      COMMON /AXIAL2/STRAINU
      COMMON /AXIAL3/STRAINDU
      COMMON /CFACTOR/CFAC1,CFAC2,EPSILON,YMAX
      COMMON /iCFACTOR/iCFAC1,iCFAC2,MPH,ilim2
      COMMON /LIMIT/LIMIT
      COMMON /ASTR1/SCC1,SCC2,SCC3
      common /iprint/nprint
      common /save/ysave,dely_dent
      LIMIT='N'
      PI=4.0*DATAN(1.0D0)
      D_AVG=0.5*(D_INNER+D_OUTER)
      SORI=P/(ES*(PI*D_AVG*T+(0.25*PI*D_INNER**2)/(ES/EG)))
      DELTAX=L/float(n_seg)
      DO 1221 J1=1,n_seg+1
         X(J1)=DELTAX*FLOAT(J1-1)
         YINI(J1)=DELTAP*L*SIN(PI*X(J1)/L)
c     save guess for transverse displacements
         y(j1)=ysave(j1)
         ytemp(j1)=y(j1)
 1221 CONTINUE
      M0=P*ECC
      DO 1241 I1=1,n_seg+1
      MOMENT=M0-((M0+M0/R)/L)*X(I1)+P*(YINI(I1)+Y(I1))
      IF((I1.EQ.N_DENT).OR.(I1.EQ.N_DENT+1)) THEN
c      find maximum moment in M-P-Phi relationship
        DMMAX=-1.0
        NMAX=0
        DO 3400 I=1,NCOUNTD
            if(dm(i).ge.dmmax) then
              dmmax=dm(i)
              nmax=i
            endif
 3400       continue
c...   find phi corresponding to moment on descending branch of M-P-Phi
            if(moment.gt.dmmax.or.nmax.le.0) THEN
            write(6,1200)
 1200  format(5x,
     & 'Current moment at dent exceeds maximum moment of M-P-Phi ',
     & 'relationship in INTER_GROUT_DESCENDING.',/,
     & 5x,'Lower axial load and continue analysis.')
c...   lower current value of axial load
            MPH=-1
            RETURN
            ENDIF
            DO 3461 KH=nmax+1,NCOUNTD
             IF((MOMENT.LE.DM(KH-1)).AND.(MOMENT.GE.DM(KH))) THEN
                PHI(I1)=DPHI(KH-1)+(DM(KH-1)-MOMENT)*
     &          (DPHI(KH)-DPHI(KH-1))/(DM(KH-1)-DM(KH))
c  Strains 
                STRAINDU(I1)=STRAIND(KH-1)+(PHI(I1)-DPHI(KH-1))*
     &          (STRAIND(KH)-STRAIND(KH-1))/(DPHI(KH)-DPHI(KH-1))
                SCC1(I1)=SC1(KH-1)+(PHI(I1)-DPHI(KH-1))*
     &          (SC1(KH)-SC1(KH-1))/(DPHI(KH)-DPHI(KH-1))
                SCC2(I1)=SC2(KH-1)+(PHI(I1)-DPHI(KH-1))*
     &          (SC2(KH)-SC2(KH-1))/(DPHI(KH)-DPHI(KH-1))
                SCC3(I1)=SC3(KH-1)+(PHI(I1)-DPHI(KH-1))*
     &          (SC3(KH)-SC3(KH-1))/(DPHI(KH)-DPHI(KH-1))
c
                GOTO 1241
             ELSE
                PHI(I1)=DPHI(NCOUNTD)-(MOMENT-DM(NCOUNTD))*
     &          (DPHI(ncountd)-DPHI(nmax))/(DM(nmax)-DM(NCOUNTD))
                STRAINDU(I1)=STRAIND(NCOUNTD)-(MOMENT-DM(NCOUNTD))*
     &          (STRAIND(NCOUNTD)-STRAIND(nmax))/(DM(nmax)-DM(NCOUNTD))
                SCC1(I1)=SC1(NCOUNTD)-(MOMENT-DM(NCOUNTD))*
     &          (SC1(NCOUNTD)-SC1(nmax))/(DM(nmax)-DM(NCOUNTD))
                SCC2(I1)=SC2(NCOUNTD)-(MOMENT-DM(NCOUNTD))*
     &          (SC2(NCOUNTD)-SC2(nmax))/(DM(nmax)-DM(NCOUNTD))
                SCC3(I1)=SC3(NCOUNTD)-(MOMENT-DM(NCOUNTD))*
     &          (SC3(NCOUNTD)-SC3(nmax))/(DM(nmax)-DM(NCOUNTD))
                GOTO 1241
             ENDIF
 3461       CONTINUE
          ELSE
            DO 7461 KHK=1,NCOUNTU
               IF((MOMENT.LE.UM(KHK)).AND.(KHK.EQ.1)) THEN
                PHI(I1)=UPHI(KHK)*MOMENT/UM(KHK)
                STRAINDU(I1)=SORI+(STRAINU(KHK)-SORI)*PHI(I1)/UPHI(KHK)
                GOTO 1241
               ELSE IF((MOMENT.LE.UM(KHK)).AND.(KHK.GT.1)) THEN
                PHI(I1)=UPHI(KHK-1)+(UPHI(KHK)-UPHI(KHK-1))*
     &          ((MOMENT-UM(KHK-1))/(UM(KHK)-UM(KHK-1)))
                STRAINDU(I1)=STRAINU(KHK-1)+(PHI(I1)-UPHI(KHK-1))*
     &          (STRAINU(KHK)-STRAINU(KHK-1))/(UPHI(KHK)-UPHI(KHK-1))
                GOTO 1241
               ELSE IF(KHK.EQ.NCOUNTU) THEN
               write(6,7000)
 7000           FORMAT(5x,'Computed moment exceeds maximum moment ',
     &                   'in M-P-Phi Undented Relationship.')
c               stop
               MPH=-1
               go to 5671
               ENDIF
 7461       CONTINUE
          ENDIF
 1241 CONTINUE
C --------------------------------------------------------------------
C     ROTATION FORMULATION
C --------------------------------------------------------------------
      THETA(1)=0.
      DO 2901 IS=2,n_seg+1
      THETA(IS)=THETA(IS-1)-DELTAX*0.5*(PHI(IS)+PHI(IS-1))
 2901 CONTINUE
C --------------------------------------------------------------------
C     CALCULATION OF THE TRIAL DEFLECTIONS
C --------------------------------------------------------------------
      YCAL(1)=0.
      DO 2911 IT=2,n_seg+1
        YCAL(IT)=YCAL(IT-1)+THETA(IT-1)*DELTAX-(2.0*PHI(IT-1)+PHI(IT))*
     &  (DELTAX**2/6.0)
 2911 CONTINUE
C --------------------------------------------------------------------
C     LINEAR CORRECTION TO SATISFY THE BOUNDARY CONDITION AT THE END
C --------------------------------------------------------------------
      DO 2371 IU=1,n_seg+1
         YCAL(IU)=YCAL(IU)-YCAL(n_seg+1)*X(IU)/L
 2371 CONTINUE
C --------------------------------------------------------------------
C     CHECK THE CONVERGENCE OF n_seg+1 STATIONS
C --------------------------------------------------------------------
         ilim2=ilim2+1
      DO 1762 ITEST=1,n_seg+1
      IF(ABS(YCAL(ITEST)-Y(ITEST)).GT.(ABS(YCAL(ITEST)/CFAC2))) THEN
c..   find maximum error
      ymaxdif=0.0
      do 1763 ii=1,n_seg+1
      error = ycal(ii) - y(ii)
      if(abs(error).gt.ymaxdif) then
      ymaxdif = abs(error)
      endif
 1763 continue
         DO 4881 IH=1,n_seg+1
         Y(IH)=YCAL(IH)
 4881    CONTINUE
           iccfac2=10
           IF(ilim2.GT.iccfac2) then
           write(6,100) iccfac2
 100  format(5x,
     & '***Non-convergence in INTER_GROUT_DESCENDING after',i3,
     & ' iterations. Target Displacement increased.')
c
      write(6,111) p,ysave(n_dent+1),y(n_dent+1),ymaxdif
 111  format(3x,'   Analysis statistics',/,
     &3x,'Current axial load =',e11.4,/,
     &3x,'Current Target Disp. (@ dent) =',e11.4,/,
     &3x,'Current computed disp. @ dent =',e11.4,/,3x,
     &'Maximum disp. error among all stations'
     &' from last two iter. cycles ='
     &,e11.4,/,3x,'Revised values for control parameters',/,)
c   Reset displacement control parameters
         ytarget=ysave(n_dent+1) + dely_dent
         pmin=0.25*pold
         pmax=pold
         write(6,92) ytarget,pmin,pmax
 92      format(3x,'*** New target displacement at dent =',f10.4,/,
     &          6x,'Lower axial load bound, pmin=',e10.3,/,
     &          6x,'Upper axial load bound, pmax=',e10.3,/)
           if(ytarget.gt.ymax) then
            write(6,1120)
1120        format(5x,'Program terminated during iteration in'
     &         ' INTER_GROUT_DESCENDING -',/,
     &      5x,'target displacement @ dent exceeds ymax.')
            stop
           endif
           ilim2=0
           go to 120
          ENDIF
          ytarget=ysave(n_dent+1)
          if(ysave(N_dent+1)-y(n_dent+1)) 110,120,115
 110      continue
          pmin=p
          p=0.5*(pmax + p)
          go to 120
 115      continue
          pmax=p
          p=0.5*(pmin + p)
 120      continue
           do 1760 i=1,n_seg+1
1760       ysave(i) = ytarget*y(i)/y(n_dent+1)
           go to 5671
       ENDIF
 1762 CONTINUE
C
C     Convergence achieved
      write(6,1768)
 1768 format(5x,'Convergence achieved in descending branch ',
     &           'of axial load-shortening response.')
      LIMIT='Y'
c
c        save last converged set of displacements
c
         do 1770 i=1,n_seg+1
         ysave(i) = ycal(i)
1770     continue
c
C --------------------------------------------------------------------
      CALL SHORTENING_GROUT(Y)
C --------------------------------------------------------------------
 5671 RETURN
      END
C --------------------------------------------------------------------
      SUBROUTINE SHORTENING_GROUT(Y)
C
C     Computes axial shortening due to axial and geometric effects
C
C --------------------------------------------------------------------
      DOUBLE PRECISION STRAINDU(100),Y(100)
      DOUBLE PRECISION SCC1(100),SCC2(100),SCC3(100)
      REAL L
      COMMON /GEO1/L,D_OUTER,D_INNER,T,DD,FY,ES,FG,EU1,fr
      COMMON /GEO2/n_seg,N_DENT,DELTAP,ECC,R,EG
      COMMON /GEO3/P,LK,pmax,pmin,pold
      COMMON /AXIAL3/STRAINDU
      COMMON /DES/SHORT_OLD
      COMMON /ASTR1/SCC1,SCC2,SCC3
      DELTAX=L/FLOAT(n_seg)
      KF=N_DENT+1
C
C     AXIAL SHORTENING DUE TO AXIAL STRAIN
C
      TOTALAX=0.
      DO 2000 LF=2,n_seg+1
         TOTALAX=TOTALAX+DELTAX*STRAINDU(LF)
 2000 CONTINUE
C
C     AXIAL SHORTENING DUE TO GEOMETRY CHANGE
C
      TOTALGE=0.
      DO 2001 LG=2,n_seg+1
         TOTALGE=TOTALGE+
     :   DELTAX-SQRT((DELTAX**2)-(Y(LG)-Y(LG-1))**2)
 2001 CONTINUE
      TOTALSH=TOTALAX+TOTALGE
      IF(TOTALSH.LT.SHORT_OLD) THEN
        WRITE(6,100)
 100    FORMAT(5x,'*** Computed axial shortening is less than',
     &  ' that from previous analysis step - Analysis terminated.')
        STOP
        ELSE
        SHORT_OLD = TOTALSH
        ENDIF
      WRITE(2,2002)P,TOTALSH,Y(KF),SCC1(KF),SCC2(KF),SCC3(KF)
      WRITE(6,2002)P,TOTALSH,Y(KF),SCC1(KF),SCC2(KF),SCC3(KF)
 2002 FORMAT(1X,F8.4,1X,F12.8,1X,F12.8,1X,F8.6,1X,F8.6,1X,F8.6)
      RETURN
      END
C
